      SUBROUTINE FLBIRD (IPRINT, INFILE, NECELL, KSGMT, KEDGE, JBINDX,
     $      JADJSG, JADJCX, JADJCY, JFLAG)
C
C NAME -- BOUNDARY TIME-INVARIANT FILE RECORD
C
C DESCRIPTION -- READS THE TIME-INVARIANT BOUNDARY FILE RECORD FOR
C          ONE EDGE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NECELL    I  NUMBER OF CELLS ON THIS EDGE
C         KSGMT     I  SEGMENT NUMBER
C         KEDGE     I  EDGE NUMBER
C         JBINDX    I  INDEX OF THE BOUNDARY CELL
C         JADJSG    I  SEGMENT NUMBER OF ADJACENT CELL
C         JADJCX    I  X-INDEX OF ADJACENT CELL
C         JADJCY    I  Y-INDEX OF ADJACENT CELL
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NUMBER OF CELLS
C         -2        NONPOSITIVE VALUE FOR SEGMENT NUMBER
C         -3        NONPOSITIVE VALUE FOR EDGE NUMBER
C         -4        ERROR IN SYSTEM READ ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAY
C
      DIMENSION JBINDX (NECELL)
      DIMENSION JADJSG (NECELL)
      DIMENSION JADJCX (NECELL)
      DIMENSION JADJCY (NECELL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE NUMBER OF CELLS AND SEGMENT EDGE NUMBER ARE POSITIVE
C
      IF (NECELL .LE. 0) GO TO 905
C
C     READ THE TIME-INVARIANT BOUNDARY FILE
C
      READ (INFILE) KSGMT, KEDGE, NECELL, (JBINDX(I), JADJSG(I),
     $     JADJCX(I), JADJCY(I), I = 1, NECELL)
C
C CHECK FOR ERROR ON READ, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 920
      GO TO 1000
C
C ERROR MESSAGE FOR NONPOSITIVE NUMBER OF CELLS
C
  905 WRITE (IPRINT, 2905) NECELL
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON RECORD READ FROM FILE
C
  920 WRITE (IPRINT, 2920) JFLAG
      JFLAG = -4
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        47H SUBROUTINE FLBIRD CALLED WITH NUMBER OF CELLS , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2920 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLBIRD FROM SYSTEM READ ROUTINE, //)
      END
