      SUBROUTINE FLPVWC (IPRINT, IOUTFL, NAMLEN, NVARBL, NPTSRC,
     $     KSGMT, JXINDX, JYINDX, JZINDX, FLOWRT, PLUMHT,
     $     MVARBL, OUTMAT, KPVEC, OUTVEC, JFLAG)
C
C NAME -- POINT SOURCE EMISSIONS FILE RECORD WRITE
C
C DESCRIPTION -- WRITES THE TIME-VARIANT POINT SOURCE EMISSIONS FILE RECORDS
C         FOR ALL VARIABLES IN ONE SEGMENT
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         IOUTFL    I  FORTRAN OUTPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         KSGMT     I  SEGMENT NUMBER
C         JXINDX    I  X-INDEX OF EMISSIONS CELL
C         JYINDX    I  Y-INDEX OF EMISSIONS CELL
C         JZINDX    I  Z-INDEX OF EMISSIONS CELL
C         FLOWRT    R  FLOW RATE
C         PLUMHT    R  EFFECTIVE PLUME HEIGHT
C         MVARBL    I  VARIABLE NAMES
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         KPVEC     I  SPACE TO STORE LIST OF SOURCES
C         OUTVEC    R  VECTOR OF EMISSIONS FOR 1 SPECIES
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE VALUE FOR NUMBER OF VARIABLES
C         -3        NONPOSITIVE VALUE FOR SEGMENT NUMBER
C         -4        ERROR IN SYSTEM WRITE ROUTINE FOR COUNTER RECORD
C         -5        ERROR IN SYSTEM WRITE ROUTINE FOR EMISSIONS LOCATION
C         -6        ERROR IN SYSTEM WRITE ROUTINE FOR EMISSIONS VALUES
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION JXINDX(NPTSRC)
      DIMENSION JYINDX(NPTSRC)
      DIMENSION JZINDX(NPTSRC)
      DIMENSION FLOWRT(NPTSRC)
      DIMENSION PLUMHT(NPTSRC)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
      DIMENSION OUTMAT(NPTSRC, NVARBL)
      DIMENSION KPVEC(NPTSRC)
      DIMENSION OUTVEC(NPTSRC)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C CHECK THE NAME LENGTH, NUMBER OF VARIABLES, AND SEGMENT NUMBER
C
      IF (NAMLEN .LE. 0) GO TO 905
      IF (NVARBL .LE. 0) GO TO 910
      IF (KSGMT .LE. 0) GO TO 915
C
C WRITE COUNTER RECORD AND CHECK FOR ERROR
C
      NPTWC = -NPTSRC
      WRITE (IOUTFL) KSGMT, NPTWC
      IF (JFLAG .NE. 0) GO TO 920
C
C IF NO POINT SOURCES IN THIS SEGMENT, RETURN
C
      IF (NPTSRC .LE. 0) GO TO 1000
C
C WRITE AND CHECK POINT SOURCE EMISSIONS LOCATION
C
      WRITE (IOUTFL) (JXINDX(K), JYINDX(K), JZINDX(K),
     $               FLOWRT(K), PLUMHT(K), K = 1, NPTSRC)
      IF (JFLAG .NE. 0) GO TO 925
C
C LOOP OVER ALL SPECIES
C
      DO 110 J = 1, NVARBL
C
C WRITE THE POINT SOURCE EMISSIONS VALUES RECORD
C
         numnul = 0
         do k=1,nptsrc
           if (outmat(k,j) .eq. 0.) numnul = numnul + 1
         enddo
         if (numnul .le. nptsrc/2) then
           ksgout = nptsrc
           WRITE (IOUTFL) ksgout, (MVARBL(I, J), I = 1, NAMLEN),
     $                  (OUTMAT(K, J), K = 1, NPTSRC)
         else
c
c  keep only non-zero values in outvec
c  store source nos. with non-zero values in kpvec
c
           know = 0
           do k=1,nptsrc
             if (outmat(k,j) .ne. 0.) then
               know = know + 1
               outvec(know) = outmat(k,j)
               kpvec(know) = k
             endif
           enddo
           if (know .ne. nptsrc - numnul) then
             write(*,*) 'Point source compression error.'
             stop
           endif
           ksgout = know
           WRITE (IOUTFL) ksgout, (MVARBL(I, J), I = 1, NAMLEN),
     $                  (OUTVEC(K), K = 1, ksgout)
c
c  look for sequences and turn into a range if possible
c
           do k=1,ksgout
             iseq = 1
             do k2=k+1,know
               if (kpvec(k2)-kpvec(k2-1) .eq. 1) then
                 iseq = iseq + 1
               else
                 go to 50 
               endif
             enddo
   50        if (iseq .gt. 2) then
               kpvec(k+1) = -(kpvec(k) + iseq - 1)
               do k2=k+2,know
                 kpvec(k2) = kpvec(k2+iseq-2)
               enddo
               know = know - iseq + 2
               do k2=know+1,ksgout
                 kpvec(k2) = 0
               enddo
             endif
           enddo
           WRITE (IOUTFL) know, (KPVEC(K), K = 1, know)
         endif
C
C CHECK FOR ERROR ON WRITE AND RETURN
C
         IF (JFLAG .NE. 0) GO TO 930
  110 CONTINUE
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF VARIABLES
C
  910 WRITE (IPRINT, 2910) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE SEGMENT NUMBER
C
  915 WRITE (IPRINT, 2915) KSGMT
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE OF COUNTER
C
  920 WRITE (IPRINT, 2920) JFLAG
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE OF EMISSIONS LOCATION
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE OF EMISSIONS VALUES
C
  930 WRITE (IPRINT, 2930) JFLAG
      JFLAG = -6
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FLPVWC CALLED WITH NAME LENGTH OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        50H SUBROUTINE FLPVWC CALLED WITH NUMBER OF VARIABLES,I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FLPVWC CALLED WITH SEGMENT NUMBER , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2920 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLPVWC FROM SYSTEM WRITE ROUTINE ,
     $        20H FOR COUNTER RECORD , //)
 2925 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLPVWC FROM SYSTEM WRITE ROUTINE,
     $        31H FOR EMISSIONS LOCATION RECORD , //)
 2930 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLPVWC FROM SYSTEM WRITE ROUTINE ,
     $        29H FOR EMISSIONS VALUES RECORD , //)
      END
