      SUBROUTINE FLSGWR (IPRINT, IOUTFL, NSGMNT, JXSGOR, JYSGOR, NXSGCL,
     $                   NYSGCL, JFLAG)
C
C NAME -- FILE SEGMENT DEFINITION WRITE
C
C DESCRIPTION -- WRITES THE FILE SEGMENT DEFINITION AT THE BEGINNING OF
C         EVERY FILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NSGMNT    I  NUMBER OF SEGMENTS
C         JXSGOR    I  X-COORDINATE OF ORIGIN FOR THIS SEGMENT
C         JYSGOR    I  Y-COORDINATE OF ORIGIN FOR THIS SEGMENT
C         NXSGCL    I  NUMBER OF X-CELLS IN THIS SEGMENT
C         NYSGCL    I  NUMBER OF Y-CELLS IN THIS SEGMENT
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NUMBER OF SEGMENTS
C         -2        ERROR IN SYSTEM WRITE ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION JXSGOR(NSGMNT)
      DIMENSION JYSGOR(NSGMNT)
      DIMENSION NXSGCL(NSGMNT)
      DIMENSION NYSGCL(NSGMNT)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE NUMBER OF SEGMENTS IS POSITIVE
C
      IF (NSGMNT .LE. 0) GO TO 905
C
C WRITE THE FILE SEGMENT DEFINITION RECORD
C
      WRITE (IOUTFL) (JXSGOR(I), JYSGOR(I), NXSGCL(I), NYSGCL(I),
     $               I=1,NSGMNT)
C
C CHECK FOR ERROR ON WRITE, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 910
      GO TO 1000
C
C ERROR MESSAGE FOR NUMBER OF SEGMENTS
C
  905 WRITE (IPRINT, 2905) NSGMNT
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE
C
  910 WRITE (IPRINT, 2910) JFLAG
      JFLAG = -2
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        50H SUBROUTINE FLSGWR CALLED WITH NUMBER OF SEGMENTS , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLSGWR FROM SYSTEM WRITE ROUTINE, //)
      END
