      SUBROUTINE FLWDRD (IPRINT, INFILE, NAMLEN, NVARBL, NXCELL,
     $                   NYCELL, NZCELL, KSGMT,  STRFHT, XMAXSP,
     $                   YMAXSP, AVESPW, AVESPE, AVESPS, AVESPN,
     $                   MVARBL, UVECTR, VVECTR, JFLAG)
C
C NAME -- WIND FILE RECORD READ
C
C DESCRIPTION -- READS THE TIME-VARIANT WIND FILE RECORDS
C         FOR ALL VARIABLES IN ONE SEGMENT
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         NZCELL    I  NUMBER OF Z-CELLS
C         KSGMT     I  SEGMENT NUMBER
C         STRFHT    R  STATION REFERENCE HEIGHT
C         XMAXSP    R  MAXIMUM SPEED IN X-DIRECTION
C         YMAXSP    R  MAXIMUM SPEED IN Y-DIRECTION
C         AVESPW    R  AVERAGE SPEED IN X-DIRECTION ON W BOUNDARY
C         AVESPE    R  AVERAGE SPEED IN X-DIRECTION ON E BOUNDARY
C         AVESPS    R  AVERAGE SPEED IN Y-DIRECTION ON S BOUNDARY
C         AVESPN    R  AVERAGE SPEED IN Y-DIRECTION ON N BOUNDARY
C         MVARBL    I  VARIABLE NAMES
C         UVECTR    R  THE INPUT U-VECTOR MATRIX
C         VVECTR    R  THE INPUT V-VECTOR MATRIX
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -7        ERROR IN SYSTEM READ ROUTINE FOR SCALARS
C         -8        ERROR IN SYSTEM READ ROUTINE FOR U-VECTOR
C         -9        ERROR IN SYSTEM READ ROUTINE FOR V-VECTOR
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
      DIMENSION UVECTR(NXCELL, NYCELL)
      DIMENSION VVECTR(NXCELL, NYCELL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ THE WIND SCALAR RECORD -- TEST FOR ERROR
C
      IF (NZCELL .EQ. 1) READ (INFILE) KSGMT, STRFHT, XMAXSP,
     $    YMAXSP, AVESPW, AVESPE,
     $               AVESPS, AVESPN
      IF (JFLAG .NE. 0) GO TO 935
C
C READ THE WIND U-VECTOR RECORD
C
      READ (INFILE) KSGMT, (MVARBL(I,1), I = 1, NAMLEN),
     $   ((UVECTR(I, J), I = 1, NXCELL), J = 1, NYCELL)
         IF (JFLAG .NE. 0) GO TO 940
C
C READ THE WIND V-VECTOR RECORD
C
      READ (INFILE) KSGMT, (MVARBL(I,2), I = 1, NAMLEN),
     $   ((VVECTR(I, J), I = 1, NXCELL), J = 1, NYCELL)
      IF (JFLAG .NE. 0) GO TO 945
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON RECORD READ OF WIND SCALARS
C
  935 WRITE (IPRINT, 2935) JFLAG
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON RECORD READ OF WIND U-VECTOR
C
  940 WRITE (IPRINT, 2940) JFLAG
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON RECORD READ OF WIND V-VECTOR
C
  945 WRITE (IPRINT, 2945) JFLAG
      JFLAG = -9
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2935 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLWDRD FROM SYSTEM READ ROUTINE,
     $        18H FOR WIND SCALARS, //)
 2940 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLWDRD FROM SYSTEM READ ROUTINE,
     $        19H FOR WIND U-VECTOR, //)
 2945 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLWDRD FROM SYSTEM READ ROUTINE ,
     $        19H FOR WIND V-VECTOR, //)
      END
