      SUBROUTINE PSFCRD (INCARD, IPRINT, NAMLEN, NVARBL, NPTSRC, NPTSRT,
     $           LINPTP, LPSRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $                   MPTSRC, MPTSRT, JPTSRT, PSFCVL, JFLAG)
      SAVE
C
C NAME -- POINT SOURCE EMISSIONS FACTORS PACKET READ
C
C DESCRIPTION -- READS THE POINT SOURCE EMISSIONS FACTORS PACKET AS PART
C                OF TIME-VARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         NPTSRT    I  NUMBER OF POINT SOURCE TYPES
C         LINPTP    I  INPUT PRINT FLAG
C         LPSRDP    I  POINT SOURCE FACTORS TABLE PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MPTSRC    I  POINT SOURCE NAMES
C         MPTSRT    I  POINT SOURCE TYPE NAMES
C         JPTSRT    I  POINT SOURCE TYPES
C
C OUTPUTS --
C         PSFCVL    R  POINT SOURCE FACTORS
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         MENDPF    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         MPTSNM    I  POINT SOURCE NAME
C         MVARNM    I  VARIABLE NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         KBEGV     I  POINTER TO BEGINNING VARIABLE LOCATION
C         KENDV     I  POINTER TO ENDING VARIABLE LOCATION
C         KBEGS     I  POINTER TO BEGINNING STATION LOCATION
C         KENDS     I  POINTER TO ENDING STATION LOCATION
C         KPTSR     I  POINT SOURCE POINTER
C         KVRBL     I  VARIABLE POINTER
C         VALFAC    R  POINT SOURCE FACTOR
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS FACTORS TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -8        POINT SOURCE NAME NOT IN POINT SOURCE LIST
C         -10       POINT SOURCE TYPE NAME NOT IN LIST
C         -14       VARIABLE NAME NOT IN VARIABLE LIST
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LPSRDP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
      DIMENSION JPTSRT(NPTSRC)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
Ctcm  DIMENSION MPTSRC(NAMLEN,NPTSRC)
      character*4 MPTSRC(NAMLEN,NPTSRC)
Ctcm  DIMENSION MPTSRT(NAMLEN,NPTSRT)
      character*4 MPTSRT(NAMLEN,NPTSRT)
      DIMENSION PSFCVL(NPTSRC,NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MENDPF(10), MPTSNM(10), MVARNM(10), MCRDID(20)
      character*4 MENDPF(10), MPTSNM(10), MVARNM(10), MCRDID(20)
Ctcm  DIMENSION MALLNM(10)
      character*4 MALLNM(10)
C
C DECLARE PACKET TRAILER AND 'ALL' REFERENCE
C
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C DECLARE PACKET TRAILER
C
      DATA MENDPF /'E', 'N', 'D', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MPTSNM, MVARNM, VALFAC, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MPTSNM, MVARNM, VALFAC, MCRDID
C
C PACK POINT SOURCE NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MPTSNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MENDPF, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C COMPARE POINT SOURCE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET POINT SOURCE POINTER TO ZERO TO INDICATE 'ALL'
C
      KPTSR = 0
      GO TO 140
C
C SET LOOP TO FIND POINT SOURCE NAME
C
  113 DO 115 J = 1, NPTSRC
C
C COMPARE INPUT POINT SOURCE NAME WITH THE LIST OF POINT SOURCE NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MPTSRC(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND POINT SOURCE NAME -- SAVE LOCATION AND SKIP OUT
C
         KPTSR = J
         GO TO 140
C
C END LOOP
C
  115 CONTINUE
C
C IF NO TYPES, WRITE ERROR MESSAGE, ELSE SET LOOP TO FIND TYPE
C
      IF (NPTSRT .LE. 0) GO TO 940
      DO 125 J = 1, NPTSRT
C
C COMPARE POINT SOURCE NAME WITH LIST OF TYPES
C
         CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MPTSRT(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 125
C
C FOUND TYPE NAME -- SET SOURCE POINTER TO NEGATIVE OF TYPE NUMBER
C
         KPTSR = -J
         GO TO 140
C
C END LOOP AND ERROR MESSAGE
C
  125 CONTINUE
      GO TO 950
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF STANDARD VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C SAVE LOCATION AND SKIP TO UNIT CONVERSION
C
         KVRBL = J
         GO TO 150
C
C END LOOP AND ERROR MESSAGE
C
  145 CONTINUE
      GO TO 970
  150 CONTINUE
C
C TEST FOR SOURCE TYPE
C
  160 IF (KPTSR .LT. 0) GO TO 190
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
      KBEGV = KVRBL
      KENDV = KVRBL
      KBEGS = KPTSR
      KENDS = KPTSR
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KPTSR .EQ. 0) KBEGS = 1
      IF (KPTSR .EQ. 0) KENDS = NPTSRC
C
C SET LOOPS FOR STORING INPUT AND DO SO
C
      DO 185 KVRBL = KBEGV, KENDV
         DO 175 KPTSR = KBEGS, KENDS
            PSFCVL(KPTSR, KVRBL) = VALFAC
C
C END LOOPS AND GET NEXT CARD
C
  175    CONTINUE
  185 CONTINUE
      GO TO 105
C
C REMOVE FLAG AND SET LOOP PARAMETERS
C
  190 KPTSR = -KPTSR
      KBEGV = KVRBL
      KENDV = KVRBL
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
C
C SET LOOPS TO STORE ALL SOURCES OF THIS TYPE
C
      DO 205 KVRBL = KBEGV, KENDV
         DO 195 J = 1, NPTSRC
C
C IF PROPER TYPE, SAVE FACTOR IN OUTPUT MATRIX
C
            IF (JPTSRT(J) .NE. KPTSR) GO TO 195
            PSFCVL(J, KVRBL) = VALFAC
C
C END LOOPS AND GET NEXT CARD
C
  195    CONTINUE
  205 CONTINUE
      GO TO 105
C
C END OF PACKET -- PRINT FACTORS TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LPSRDP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT FACTORS IN LOOP
C
      DO 225 K = 1, NPTSRC
         DO 215 J = 1, NVARBL
            WRITE (IPRINT, 2215)(MPTSRC(I,K), I=1,NAMLEN),
     $                       (MVARBL(I,J), I=1,NAMLEN), PSFCVL(J,K)
  215    CONTINUE
  225 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR POINT SOURCE NAME NOT IN POINT SOURCE LIST
C
  940 WRITE (IPRINT, 2940) MPTSNM
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR POINT SOURCE NAME NOT IN TYPE LIST
C
  950 WRITE (IPRINT, 2950) MPTSNM
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  970 WRITE (IPRINT, 2970) MVARNM
      JFLAG = -14
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, F10.0, 30X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, F10.4, 30X, 20A1)
 2210 FORMAT (1H1, 8X, 35HPOINT SOURCE EMISSION FACTORS TABLE, //,
     $        46H  SOURCE NAME   VARIABLE NAME   SOURCE FACTOR , //)
 2215 FORMAT (1X, 10A1, 5X, 10A1, F15.4, /)
 2940 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        36H UNABLE TO LOCATE POINT SOURCE NAME , 10A1,
     $        23H IN POINT SOURCES TABLE, //,
     $        32H CHECK POINT SOURCE SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        36H UNABLE TO LOCATE POINT SOURCE NAME , 10A1,
     $        28H IN POINT SOURCE TYPES TABLE, //,
     $        32H CHECK POINT SOURCE SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLES TABLE, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
