      SUBROUTINE CELLHT(IPRINT, NZCELL, NZLOWR, NZUPPR, KZCLL,
     $     ZHTSUR, ZMINLW, ZMINUP, ZHTDIF, ZHTTOP, RMISSV, ZHTCLL,
     $     JFLAG)
C
C NAME --  VERTICAL CELL HEIGHT
C
C DESCRIPTION -- CALCULATES THE HEIGHT OF THE CENTER OF A VERTICAL CELL
C      ABOVE GROUND LEVEL
C
C PROGRAMMER -- DC WHITNEY, JUNE 1977
C
C INPUTS --
C         IPRINT     I   FORTRAN OUTPUT UNIT
C         NZCELL     I   NUMBER OF Z-CELLS
C         NZLOWR     I   NUMBER OF Z-CELLS IN LOWER LAYER
C         NZUPPR     I   NUMBER OF Z-CELLS IN UPPER LAYER
C         KZCLL      I   LEVEL NUMBER OF THIS CELL
C         ZHTSUR     R   HEIGHT OF THE SURFACE LAYER
C         ZMINLW     R   MINIMUM HEIGHT OF A LOWER LAYER CELL
C         ZMINUP     R   MINIMUM HEIGHT OF AN UPPER LAYER CELL
C         ZHTDIF     R   HEIGHT OF DIFFUSION BREAK
C         ZHTTOP     R   HEIGHT OF TOP OF THE REGION
C         RMISSV     R   VALUE FOR MISSING VARIABLE
C
C OUTPUTS --
C         ZHTCLL     R   HEIGHT OF THE CENTER OF THIS CELL
C         JFLAG      I   COMPLETION FLAG
C
C LOCAL VARIABLES --
C         OFFSET    R  NUMBER OF VERTICAL UNITS TO CENTER OF CELL
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C
C OTHER INFORMATION --
C
C
C
C
C INITIALIZE COMPLETION FLAG AND RETURN VALUE
C
      JFLAG = 0
      ZHTCLL = RMISSV
C
C SET CELL OFFSET COUNTER
C
      OFFSET = 1.5
      IF (ZHTSUR .LE. 0.0) OFFSET = 0.5
C
C SURFACE LAYER IS SPECIAL CASE -- TEST FOR IT
C
      IF (KZCLL .NE. 1) GO TO 110
      IF (ZHTSUR .LE. 0.0) GO TO 110
C
C SET CELL HEIGHT TO CENTER OF SURFACE LAYER AND RETURN
C
      ZHTCLL = 0.5 * ZHTSUR
      GO TO 1000
C
C TEST FOR CELL BEING IN LOWER OR UPPER LAYER
C
  110 IF (KZCLL .GT. NZLOWR + IFIX(OFFSET)) GO TO 210
C
C LOWER LAYER -- CHECK FOR DIFFUSION BELOW MINIMUM LOWER VALUE
C
      IF (ZHTDIF .GT. ZHTSUR + FLOAT(NZLOWR) * ZMINLW) GO TO 120
C
C IT IS TOO LOW -- SET VALUE TO CENTER OF APPROPRIATE LEVEL AND RETURN
C
      ZHTCLL = ZHTSUR + (FLOAT(KZCLL) - OFFSET) * ZMINLW
      GO TO 1000
C
C CHECK FOR DIFFUSION BREAK ABOVE MINIMUM UPPER VALUE
C
  120 IF (ZHTDIF .GT. ZHTTOP - FLOAT(NZUPPR) * ZMINUP) GO TO 130
C
C BREAK BETWEEN SURFACE AND TOP -- SET HEIGHT ACCORDINGLY AND RETURN
C
      ZHTCLL = ZHTSUR + (FLOAT(KZCLL) - OFFSET) * (ZHTDIF - ZHTSUR) /
     $         FLOAT(NZLOWR)
      GO TO 1000
C
C BREAK IS ABOVE TOP -- SET HEIGHT ACCORDINGLY AND RETURN
C
  130 ZHTCLL = ZHTSUR + (FLOAT(KZCLL) - OFFSET) * (ZHTTOP -
     $         FLOAT(NZUPPR) * ZMINUP) / FLOAT(NZLOWR)
      GO TO 1000
C
C UPPER LAYER -- CHECK FOR DIFFUSION HEIGHT BELOW SURFACE LAYER
C
  210 IF (ZHTDIF .GT. ZHTSUR + FLOAT(NZLOWR) * ZMINLW) GO TO 220
C
C BREAK TOO LOW -- SET CELL HEIGHT ACCORDINGLY AND RETURN
C
      ZHTCLL = ZHTSUR + FLOAT(NZLOWR) * ZMINLW + (ZHTTOP - ZHTSUR -
     $         FLOAT(NZLOWR) * ZMINLW) * (FLOAT(KZCLL - NZLOWR) -
     $         OFFSET) / FLOAT(NZUPPR)
      GO TO 1000
C
C CHECK FOR BREAK ABOVE MINIMUM UPPER VALUE
C
  220 IF (ZHTDIF .GT. ZHTTOP - FLOAT(NZUPPR) * ZMINUP) GO TO 230
C
C BREAK BETWEEN SURFACE AND TOP -- SET HEIGHT ACCORDINGLY AND RETURN
C
      ZHTCLL = ZHTSUR + ZHTDIF + (ZHTTOP - ZHTDIF - ZHTSUR) *
     $         (FLOAT(KZCLL - NZLOWR) - OFFSET) / FLOAT(NZUPPR)
      GO TO 1000
C
C BREAK ABOVE TOP -- SET HEIGHT ACCORDINGLY AND RETURN
C
  230 ZHTCLL = ZHTTOP - (FLOAT(NZCELL - KZCLL) + 0.5) * ZMINUP
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
      END
