      SUBROUTINE CNSTRD(INCARD, IPRINT, IMATFL, NAMLEN, NVARBL,
     $     NSBRGN, NXCELL, NYCELL, KCNST, LINPTP,
     $  RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MSBRGN,
     $  JRGRID, JMTHDN, SMTHMN, SMTHMX, BASGRD, OUTMAT, JFLAG)
C
C NAME -- CONSTANTS PACKET READ
C
C DESCRIPTION -- READS THE CONSTANTS PACKET AS PART OF TIME-VARIANT
C                DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         IMATFL    I  OUTPUT MATRIX FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF YCELLS
C         KCNST     I  METHOD NUMBER FOR CONSTANTS
C         LINPTP    I  INPUT PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MSBRGN    I  SUBREGION NAMES
C         JRGRID    I  REGIONAL GRID
C         JMTHDN    I  METHOD NUMBERS
C         BASGRD    R  OUTPUT GRID
C         SMTHMN    R  MINUMUM ALLOWABLE VALUES
C         SMTHMX    R  MAXIMUM ALLOWABLE VALUES
C
C OUTPUTS --
C         OUTMAT    R  OUTPUT VALUES MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         KVRBL     I  VARIABLE NUMBER
C         KZCLL     I VERTICAL LEVEL NUMBER
C         KSBRG     I  SUBREGION NUMBER
C         KBEGV     I  BEGINNING LOCATION FOR VARIABLE LOOP
C         KENDV     I  ENDING LOCATION FOR VARIABLE LOOP
C         KBEGS     I  BEGINNING LOCATION FOR SUBREGION LOOP
C         KENDS     I  ENDING LOCATION FOR SUBREGION LOOP
C         CNSTVL    R  INPUT VALUE FOR CONSTANT
C         MENDCN    I  PACKET TRAILER NAME
C         MVARNM    I  INPUT VARIABLE NAME
C         MSBRNM    I  INPUT SUBREGION NAME
C         MALLNM    I  REFERENCE NAME FOR ALL
C         MCRDID    I  CARD IDENTIFICATION
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -7        ERROR FROM TXTPAK OF SUBREGION NAME
C         -8        ERROR FROM COMPAR OF PACKET TRAILER
C         -9        ERROR FROM COMPAR OF SUBREGION 'ALL'
C         -10       ERROR FROM COMPAR OF SUBREGION NAME
C         -11       SUBREGION NAME NOT IN LIST
C         -12       ERROR FROM TXTPAK OF VARIABLE NAME
C         -13       ERROR FROM COMPAR OF VARIABLE 'ALL'
C         -14       ERROR FROM COMPAR OF VARIABLE NAME
C         -15       VARIABLE NAME NOT IN VARIABLE LIST
C         -16       INCORRECT METHOD REQUEST
C         -17       ERROR IN MATGET
C         -18       ERROR IN MATPUT
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION OUTMAT(1)
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
Ctcm  DIMENSION MSBRGN(NAMLEN,NSBRGN)
      character*4 MSBRGN(NAMLEN,NSBRGN)
      DIMENSION JRGRID(NXCELL, NYCELL)
      DIMENSION JMTHDN(NSBRGN, NVARBL)
      DIMENSION BASGRD(NXCELL, NYCELL)
      DIMENSION SMTHMN(NSBRGN, NVARBL)
      DIMENSION SMTHMX(NSBRGN, NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MVARNM(10), MENDCN(10), MSBRNM(10), MCRDID(20)
      character*4 MVARNM(10), MENDCN(10), MSBRNM(10), MCRDID(20)
Ctcm  DIMENSION MALLNM(10)
      character*4 MALLNM(10)
C
C SET VERTICAL LEVEL NUMBER
C
      DATA KZCLL /1/
C
C DECLARE PACKET TRAILER AND 'ALL' REFERENCE
      DATA MENDCN /'E', 'N', 'D', 7*' '/
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSBRNM, MVARNM, CNSTVL, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSBRNM, MVARNM, CNSTVL, MCRDID
C
C PACK SUBREGION NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MSBRNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MENDCN, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 1000
C
C COMPARE SUBREGION NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET SUBREGION POINTER TO ZERO TO INDICATE 'ALL'
C
      KSBRG = 0
      GO TO 140
C
C SET LOOP TO FIND SUBREGION NAME
C
  113 DO 115 K = 1, NSBRGN
C
C COMPARE INPUT SUBREGION NAME WITH THE LIST OF SUBREGION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MSBRGN(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND SUBREGION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSBRG = K
         GO TO 140
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  115 CONTINUE
      GO TO 955
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C FOUND VARIABLE NAME -- SAVE LOCATION AND SKIP OUT
C
         KVRBL = J
         GO TO 150
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  145 CONTINUE
      GO TO 975
C
C VERIFY METHOD NUMBER AND DO UNIT CONVERSION ON INPUT VALUE
C
  150 KBEGV = KVRBL
C
C USE FIRST UNIT CONVERSION IF ALL
C
      IF (KVRBL .EQ. 0) KVRBL = 1
      KBEGS = KSBRG
      IF (KSBRG .EQ. 0) KSBRG = 1
      IF (KCNST .NE. JMTHDN(KSBRG,KVRBL) ) GO TO 980
      CALL UNTCNV(CNSTVL, FACMLT(KVRBL), FACADD(KVRBL), SMOLWT(KVRBL),
     $            RMISSV, RMISSV, CNSTVL)
C
C CHECK THE VALUE AGAINST RANGE -- MESSAGE IF OUTSIDE
C
      IF (CNSTVL .GE. SMTHMN(KSBRG, KVRBL)) GO TO 160
      WRITE (IPRINT, 2150) MVARNM, MSBRNM, SMTHMN(KSBRG, KVRBL)
      CNSTVL = SMTHMN(KSBRG, KVRBL)
      GO TO 170
  160 IF (CNSTVL .LE. SMTHMX(KSBRG, KVRBL)) GO TO 170
      WRITE (IPRINT, 2160) MVARNM, MSBRNM, SMTHMX(KSBRG, KVRBL)
      CNSTVL = SMTHMX(KSBRG, KVRBL)
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  170 KVRBL = KBEGV
      KENDV = KVRBL
      KSBRG = KBEGS
      KENDS = KSBRG
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KSBRG .EQ. 0) KBEGS = 1
      IF (KSBRG .EQ. 0) KENDS = NSBRGN
C
C SET VARIABLE LOOP
C
      DO 235 K = KBEGV, KENDV
         KVRBL = K
C
C GET OUTPUT GRID FOR THIS VARIABLE
C
         CALL MATGET(IPRINT, IMATFL, NXCELL, NYCELL, KZCLL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 985
C
C SET SUBREGION LOOP
C
         DO 225 KSBRG = KBEGS, KENDS
C
C SET LOOPS TO SEARCH REGIONAL GRID
C
            DO 215 J = 1, NYCELL
               DO 205 I = 1, NXCELL
C
C IF CORRECT SUBREGION, STORE VALUE
C
                  IF (JRGRID(I, J) .EQ. KSBRG) BASGRD(I, J) = CNSTVL
C
C END INNER LOOPS
C
  205          CONTINUE
  215       CONTINUE
C
C END SUBREGION LOOP AND REPLACE OUTPUT GRID
C
  225    CONTINUE
         CALL MATPUT(IPRINT, IMATFL, NXCELL, NYCELL, KZCLL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 990
C
C END VARIABLE LOOP AND GET NEXT CARD
C
  235 CONTINUE
      GO TO 105
C
C ERROR MESSAGE FOR SUBREGION NAME NOT IN LIST
C
  955 WRITE (IPRINT, 2955) MSBRNM
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  975 WRITE (IPRINT, 2975) MVARNM
      JFLAG = -15
      GO TO 1000
C
C ERROR MESSAGE FOR INCORRECT METHOD REQUEST
C
  980 WRITE (IPRINT, 2980) MVARNM, MSBRNM
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET
C
  985 WRITE (IPRINT, 2985) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATPUT
C
  990 WRITE (IPRINT, 2990) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -18
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, F10.0, 30X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, F14.4, 26X, 20A1)
 2150 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        14H IN SUBREGION , 10A1, //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2160 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        14H IN SUBREGION , 10A1, //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        33H UNABLE TO LOCATE SUBREGION NAME , 10A1,
     $        18H IN SUBREGION LIST, //,
     $        34H CHECK SUBREGION NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2975 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLE LIST, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2980 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE METHOD 'CONSTANT' HAS NOT BEEN SPECIFIED ,
     $        //, 14H FOR VARIABLE , 10A1, 14H IN SUBREGION , 10A1,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2985 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        42H RETURNED TO CNSTRD FROM SUBROUTINE MATGET ,
     $        14H FOR VARIABLE , 10A1, //)
 2990 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        42H RETURNED TO GDVLRD FROM SUBROUTINE MATPUT ,
     $        14H FOR VARIABLE , 10A1, //)
      END
