      SUBROUTINE CNTLRD (INCARD, IPRINT, NAMLEN, NIDLEN, NOPTIN, MFILNM,
     $   JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILID, JOPTIN, MSPECS, JFLAG)
C
C NAME -- CONTROL PACKET READ
C
C DESCRIPTION -- READS THE CONTROL PACKET AT THE BEGINNING OF
C         EVERY PROGRAM THAT WRITES A FILE
C
C PROGRAMMER -- GW LUNDBERG/SAI  MAY 1977
C
C MODIFIER   -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NIDLEN    I  NUMBER OF WORDS IN IDENTIFICATION FIELD
C         NOPTIN    I  NUMBER OF CONTROL OPTIONS
C         MFILNM    I  FILE NAME (LENGTH)
C
C OUTPUTS --
C         JBEGDT    I  BEGINNING DATE
C         JENDDT    I  ENDING DATE
C         BEGTIM    R  BEGINNING TIME
C         ENDTIM    R  ENDING TIME
C         MFILID    I  FILE IDENTIFICATION (ID.LENGTH)
C         JOPTIN    I  CONTROL OPTIONS (NO.OPTIONS)
C         MSPECS    I  SPECIES NAMES (LENGTH, NO.SPECIES)
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NCNTRL    I  NUMBER OF WORDS IN PACKET HEADER
C         NENDCN    I  NUMBER OF WORDS IN PACKET TRAILER
C         NINWRD    I  NUMBER OF WORDS IN INPUT LINE
C         NITEMS    I  NUMBER OF VALUES IN INPUT LINE
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         NSPECS    I  NUMBER OF SPECIES
C         KSTRT     I  POINTER TO STARTING LOCATION IN OPTIONS VECTOR
C         KSTOP     I  POINTER TO STOPPING LOCATION IN OPTIONS VECTOR
C         MCNTRL    I  PACKET HEADER NAME
C         MENDCN    I  PACKET TRAILER NAME
C         MINWRD    I  INPUT LINE
C         MCRDID    I  CARD IDENTIFICATION
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         TIMERD    READS BEGINNING AND ENDING DATE/TIME FROM CARD
C
C ERROR CONDITIONS --
C         -6        MISMATCH IN NAME OF PACKET HEADER
C         -7        ERROR IN TXTPAK FOR FILE NAME
C         -8        ERROR IN COMPAR FOR FILE NAME
C         -9        MISMATCH IN NAME OF FILE NAME
C         -10       ERROR IN TXTPAK FOR SPECIES NAME
C         -11       BLANK SPECIES NAME
C         -12       ERROR IN COMPAR FOR SPECIES NAME
C         -13       DUPLICATE SPECIES NAME
C         -14       ERROR IN TIMERD
C         -15       ERROR IN TXTPAK FOR PACKET TRAILER
C         -16       ERROR IN COMPAR FOR PACKET TRAILER
C         -17       MISMATCH IN NAME OF PACKET TRAILER
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MFILNM(NAMLEN)
      character*4 MFILNM(NAMLEN)
Ctcm  DIMENSION MFILID(NIDLEN)
      character*4 MFILID(NIDLEN)
      DIMENSION JOPTIN(NOPTIN)
Ctcm  DIMENSION MSPECS(NAMLEN,1)
      character*4 MSPECS(NAMLEN,1)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MCNTRL(7), MENDCN(3), MINWRD(60), MCRDID(20)
      character*4 MCNTRL(7), MENDCN(3), MINWRD(60), MCRDID(20)
C
C DECLARE PACKET HEADER AND TRAILER
C
      DATA MCNTRL /'C', 'O', 'N', 'T', 'R', 'O', 'L'/
      DATA MENDCN /'E', 'N', 'D'/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA NCNTRL /7/
      DATA NENDCN /3/
      DATA NINWRD /60/
      DATA NITEMS /6/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND PRINT THE PACKET NAME CARD
C
      READ (INCARD, 1005) MINWRD, MCRDID
      WRITE(IPRINT, 2005) MINWRD, MCRDID
C
C PACK THE PACKET NAME
C
      CALL TXTPAK(IPRINT, NINWRD, MINWRD, NPACKD, JFLAG)
C
C VERIFY THAT IT IS CORRECT
C
      CALL COMPAR(IPRINT, NCNTRL, MCNTRL, MINWRD, JFLAG)
      IF (JFLAG .NE. 1) GO TO 930
C
C READ AND PRINT THE FILE NAME CARD
C
      READ (INCARD, 1005) MINWRD, MCRDID
      WRITE(IPRINT, 2005) MINWRD, MCRDID
C
C PACK THE FILE NAME
C
      CALL TXTPAK(IPRINT, NINWRD, MINWRD, NPACKD, JFLAG)
C
C VERIFY THAT IT IS CORRECT
C
      CALL COMPAR(IPRINT, NAMLEN, MFILNM, MINWRD, JFLAG)
      IF (JFLAG .NE. 1) GO TO 945
C
C READ AND PRINT THE FILE HEADER
C
      READ (INCARD, 1010)(MFILID(I), I=1,NIDLEN), MCRDID
      WRITE(IPRINT, 2010)(MFILID(I), I=1,NIDLEN), MCRDID
C
C SET LOOP TO READ OPTION CARDS
C
      DO 115 J=1, NOPTIN, NITEMS
         KSTRT = J
         KSTOP = J + NITEMS -1
C
C READ AND PRINT OPTION CARDS
C
         READ (INCARD, 1015)(JOPTIN(I), I=KSTRT, KSTOP), MCRDID
         WRITE(IPRINT, 2015)(JOPTIN(I), I=KSTRT, KSTOP), MCRDID
  115 CONTINUE
C
C CAPTURE AND TEST THE SPECIES COUNT
C
      NSPECS = JOPTIN(1)
      IF (NSPECS .LE. 0) GO TO 210
C
C SET LOOP TO READ AND PRINT SPECIES NAMES
C
      DO 145 K=1,NSPECS
         READ (INCARD, 1020)(MSPECS(I,K), I=1,NAMLEN), MCRDID
         WRITE(IPRINT, 2020)(MSPECS(I,K), I=1,NAMLEN), MCRDID
C
C PACK THE SPECIES NAME AND CHECK FOR BLANK
C
         CALL TXTPAK(IPRINT, NAMLEN, MSPECS(1,K), NPACKD, JFLAG)
         IF (NPACKD .LE. 0) GO TO 955
C
C SET LOOP TO CHECK AGAINST ALL OTHER NAMES
C
         IF (K .EQ. 1) GO TO 145
         KSTOP = K-1
         DO 135 J = 1,KSTOP
C
C COMPARE NAMES FOR MATCH
C
            CALL COMPAR(IPRINT, NAMLEN, MSPECS(1,J), MSPECS(1,K),
     $                  JFLAG)
            IF (JFLAG .EQ. 1) GO TO 965
  135    CONTINUE
C
C END OF SPECIES NAME LOOP
C
  145 CONTINUE
C
C CALL TIME CARD READ ROUTINE
C
  210 CALL TIMERD(INCARD, IPRINT, JBEGDT, JENDDT, BEGTIM, ENDTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 970
C
C READ AND PRINT THE PACKET END CARD
C
      READ (INCARD, 1005) MINWRD, MCRDID
      WRITE (IPRINT, 2005) MINWRD, MCRDID
C
C PACK THE PACKET END CARD
C
      CALL TXTPAK(IPRINT, NINWRD,MINWRD, NPACKD, JFLAG)
C
C VERIFY THAT IT IS CORRECT
C
      CALL COMPAR(IPRINT, NENDCN, MENDCN, MINWRD, JFLAG)
      IF (JFLAG .NE. 1) GO TO 985
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON PACKET HEADER
C
  930 WRITE (IPRINT, 2930) (MINWRD(I),I=1,NCNTRL), MCNTRL
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON FILE NAME
C
  945 WRITE (IPRINT, 2945) (MINWRD(I),I=1,NAMLEN), MFILNM
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK SPECIES NAME
C
  955 WRITE (IPRINT, 2955)
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR DUPLICATE SPECIES NAME
C
  965 WRITE (IPRINT, 2965)
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR FROM TIMERD
C
  970 WRITE (IPRINT, 2970) JFLAG
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN PACKET TRAILER
C
  985 WRITE (IPRINT, 2985) (MINWRD(I),I=1,NENDCN), MENDCN
      JFLAG = -17
C
C RETURN TO CALLING RETURN
C
 1000 RETURN
C
C FORMATS
C
 1005 FORMAT (60A1, 20A1)
 1010 FORMAT (60A1, 20A1)
 1015 FORMAT (6I10, 20A1)
 1020 FORMAT (10A1, 50X, 20A1)
 2005 FORMAT (1X, 60A1, 20A1)
 2010 FORMAT (1X, 60A1, 20A1)
 2015 FORMAT (1X, 6I10, 20A1)
 2020 FORMAT (1X, 10A1, 50X, 20A1)
 2930 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        40H MISMATCH BETWEEN THE INPUT PACKET NAME , 10A1, //,
     $        29H AND THE EXPECTED PACKET NAME, 7A1,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2945 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        38H MISMATCH BETWEEN THE INPUT FILE NAME , 10A1, //,
     $        27H AND THE EXPECTED FILE NAME, 10A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******, /,
     $        39H BLANK SPECIES NAMES ARE NOT ACCEPTABLE, /,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2965 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******, /,
     $        39H ABOVE SPECIES NAME IS A DUPLICATE NAME, /,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        I10, 42H RETURNED TO CNTLRD FROM SUBROUTINE TIMERD,//)
 2985 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******, /,
     $        44H MISMATCH BETWEEN THE INPUT PACKET END CARD , 3A1,
     $        //, 34H AND THE EXPECTED PACKET END CARD , 3A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
