      SUBROUTINE FILVER (IPRINT, INFILE, NAMLEN, NIDLEN, NSGMNT, NSPECS,
     $   NSCRTC, NXCELL, NYCELL, NZCELL, NZLOWR, NZUPPR, JBEGDT, JENDDT,
     $   JUTMZN, BEGTIM, ENDTIM, XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD,
     $   YCELLD, ZHTSUR, ZMINLW, ZMINUP, JXSGOR, JYSGOR, NXSGCL, NYSGCL,
     $   MFILNM, JSCRTC, RSCRTC, MSPECS, JFLAG)
C
C NAME -- FILE HEADER RECORD VERIFICATION
C
C DESCRIPTION -- VERIFIES THAT THE INFORMATION IN THE FOUR FILE HEADER
C                RECORDS MATCHES THE INFORMATION IN CORE.
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C MODIFICATIONS:
C
C      --  IF TEMPERATURE FILE HEADER HAS NON-ZERO NUMBER OF
C          LAYERS, SET FLAG L3DTMP TO TRUE TO INDICATE THAT A 
C          3D TEMPERATURE FILE IS IN USE.  ADDED COMMON BLOCK
C          TMPCON TO TRANSFER FLAG TO OTHER ROUTINES.  THIS MOD IS
C          NEEDED TO ALLOW PTSRCE PROCESSOR TO USE 3D INFORMATION
C          IN CALCULATING PLUME RISE.
C          (TCM, 6/15/94)
C
C INPUTS --
C         NAMLEN     I  NAME LENGTH
C         NIDLEN     I  IDENTIFICATION FIELD LENGTH
C         NSGMNT     I  NUMBER OF SEGMENTS
C         NSPECS     I  NUMBER OF SPECIES
C         NSCLFT     I  NUMBER OF WORDS LEFT IN SCRATCH
C         NXCELL     I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL     I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL     I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR     I  NUMBER OF CELLS IN LOWER VERTICAL LAYER
C         NZUPPR     I  NUMBER OF CELLS IN UPPER VERTICAL LAYER
C         JBEGDT     I  BEGINNING DATE
C         JENDDT     I  ENDING DATE
C         JUTMZN     I  UTM ZONE NUMBER
C         BEGTIM     R  BEGINNING TIME
C         ENDTIM     R  ENDING TIME
C         XUTMOR     R  X-COORDINATE OF UTM ORIGIN
C         YUTMOR     R  Y-COORDINATE OF UTM ORIGIN
C         XREGOR     R  X-COORDINATE OF REGION ORIGIN
C         YREGOR     R  Y-COORDINATE OF REGION ORIGIN
C         XCELLD     R  LENGTH OF CELL IN X-DIRECTION
C         YCELLD     R  LENGTH OF CELL IN Y-DIRECTION
C         ZHTSUR     R  CELL HEIGHT, SURFACE LAYER
C         ZMINLW     R  MINIMUM CELL HEIGHT, LOWER LAYER
C         ZMINUP     R  MINIMUM CELL HEIGHT, UPPER LAYER
C         JXSGOR     I  X-COORDINATES OF SEGMENT ORIGINS
C         JYSGOR     I  Y-COORDINATES OF SEGMENT ORIGINS
C         NXSGCL     I  NUMBER OF X-CELLS IN EACH SEGMENT
C         NYSGCL     I  NUMBER OF Y-CELLS IN EACH SEGMENT
C         MFILNM     I  FILE NAME
C         JSCRTC     I  INTEGER SCRATCH FOR PARTITIONING
C         RSCRTC     R  REAL SCRATCH FOR PARTITIONING
C         MSPECS     I  SPECIES NAMES
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NSGLOC    I  NUMBER OF SEGMENTS FROM FILE
C         NSPLOC    I  NUMBER OF SPECIES FROM FILE
C         NFIRST    I  NUMBER OF WORDS IN FIRST RECORD
C         NSECND    I  NUMBER OF WORDS IN SECOND RECORD
C         NSGLEN    I  NUMBER OF WORDS IN ONE SEGMENT ENTRY
C         KSGMT     I  SEGMENT NUMBER
C         KSPCS     I  SPECIES NUMBER
C         KINDX     I  INDEX TO SCRATCH STORAGE OF SPECIES
C
C ROUTINES CALLED --
C         COMPAR    I  COMPARES TWO ALPHABETIC TEXT STRINGS
C         FLMDRD    I  READS FILE HEADER RECORD
C         FLRGRD    I  READS FILE REGION  RECORD
C         FLSGRD    I  READS FILE SEGMENT RECORD
C         FLSPRD    I  READS FILE SPECIES RECORD
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE FILE IDENTIFICATION LENGTH
C         -3        INSUFFICIENT SCRATCH FOR FIRST RECORD
C         -4        INSUFFICIENT SCRATCH FOR SECOND RECORD
C         -5        INSUFFICIENT SCRATCH FOR THIRD RECORD
C         -6        INSUFFICIENT SCRATCH FOR FOURTH RECORD
C         -11       ERROR IN FILE HEADER READ
C         -12       ERROR IN COMPAR OF FILE HEADER
C         -13       MISMATCH OF FILE NAME
C         -14       MISMATCH IN SEGMENT COUNT
C         -15       MISMATCH IN SPECIES COUNT
C         -16       LATE START DATE
C         -17       LATE START TIME
C         -18       EARLY END DATE
C         -19       EARLY END TIME
C         -21       ERROR IN FILE REGION READ
C         -22       MISMATCH IN MISMATCH IN UTM ZONE NUMBER
C         -23       MISMATCH IN UTM ORIGIN X-VALUE
C         -24       MISMATCH IN UTM ORIGIN Y-VALUE
C         -25       MISMATCH IN REGION ORIGIN X-VALUE
C         -26       MISMATCH IN REGION ORIGIN Y-VALUE
C         -27       MISMATCH IN CELL SIZE X-VALUE
C         -28       MISMATCH IN CELL SIZE Y-VALUE
C         -29       MISMATCH IN NUMBER OF X-CELLS
C         -30       MISMATCH IN NUMBER OF Y-CELLS
C         -31       MISMATCH IN NUMBER OF Z-CELLS
C         -32       MISMATCH IN NUMBER OF LOWER Z-CELLS
C         -33       MISMATCH IN NUMBER OF UPPER Z-CELLS
C         -34       MISMATCH IN HEIGHT OF SURFACE LAYER
C         -35       MISMATCH IN HEIGHT OF UPPER LAYER
C         -36       MISMATCH IN HEIGHT OF UPPER LAYER
C         -41       ERROR IN FILE SEGMENTATION READ
C         -42       MISMATCH IN SEGMENT ORIGIN X-CELL
C         -43       MISMATCH IN SEGMENT ORIGIN Y-CELL
C         -44       MISMATCH IN NUMBER OF SEGMENT X-CELLS
C         -45       MISMATCH IN NUMBER OF SEGMENT Y-CELLS
C         -47       ERROR IN FILE SPECIES READ
C         -48       ERROR IN SPECIES NAME COMPARE
C         -49       MISMATCH IN SPECIES NAME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MFILNM(NAMLEN)
      character*4 MFILNM(NAMLEN)
      DIMENSION JXSGOR(NSGMNT)
      DIMENSION JYSGOR(NSGMNT)
      DIMENSION NXSGCL(NSGMNT)
      DIMENSION NYSGCL(NSGMNT)
      DIMENSION JSCRTC(NSCRTC)
      DIMENSION RSCRTC(NSCRTC)
Ctcm  DIMENSION MSPECS(NAMLEN,NSPECS)
      character*4 MSPECS(NAMLEN,NSPECS)
C
C COMMON FOR 3D TEMPERATURE FLAG
C
      COMMON /TMPCON/ L3DTMP
      LOGICAL L3DTMP
C
      CHARACTER*10 MTEMP1, MTEMP2
C
C SET CERTAIN PARAMETERS
C
      DATA NFIRST /76/
      DATA NSECND /15/
      DATA NSGLEN /4/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C CHECK THE NAME AND IDENTIFICATION LENGTH
C
      IF (NAMLEN .LE. 0) GO TO 902
      IF (NIDLEN .LE. 0) GO TO 904
C
C CHECK THE AMOUNT OF AVAILBLE SCRATCH
C
      IF (NSCRTC .LT. NFIRST) GO TO 906
      IF (NSCRTC .LT. NSECND) GO TO 908
      IF (NSCRTC .LT. NAMLEN*NSPECS) GO TO 910
      IF (NSCRTC .LT. NSGLEN*NSGMNT) GO TO 912
C
C
C READ THE FILE HEADER
C
      CALL FLHDRD(IPRINT, INFILE, NAMLEN, NIDLEN, JSCRTC(1), JSCRTC(2),
     $          JSCRTC(3), JSCRTC (4), RSCRTC(5), RSCRTC(6), JSCRTC(7),
     $          JSCRTC(17), JFLAG)
      IF (JFLAG .LT. 0) GO TO 922
C
C IF THIS IS A TEMPERATURE FILE, SET 3D TEMPERATURE FLAG (ADDED 6/15/94, TCM)
C
      WRITE(MTEMP1,'(10A1)') (MFILNM(I),I=1,10)
      WRITE(MTEMP2,'(10A1)') (JSCRTC(I),I=7,16)
      IF (MTEMP1 .EQ. 'TEMPERATUR') THEN
          IF (MTEMP2 .EQ. 'TEMPERATUR') THEN
             L3DTMP = .FALSE.
          ELSEIF (MTEMP2 .EQ. 'TEMPER3D  ') THEN
             L3DTMP = .TRUE.
             READ(MTEMP1,'(10A1)') (JSCRTC(I),I=7,16)
          ENDIF
      ENDIF
C
C COMPARE FILE HEADER NAMES
C
      CALL COMPAR(IPRINT, NAMLEN, MFILNM, JSCRTC(7), JFLAG)
      IF (JFLAG .EQ. 0) GO TO 926
C
C SAVE FILE VALUES FOR SEGMENTS AND SPECIES
C
      NSGLOC = JSCRTC(1)
      NSPLOC = JSCRTC(2)
C
C IF BOTH NON-ZERO, COMPARE NUMBER OF SEGMENTS AND NUMBER OF SPECIES
C
      IF (NSGMNT .NE. 0 .AND. JSCRTC(1) .NE. 0 .AND. NSGMNT .NE.
     $    JSCRTC(1)) GO TO 928
      IF (NSPECS .NE. 0 .AND. JSCRTC(2) .NE. 0 .AND. NSPECS .NE.
     $    JSCRTC(2)) GO TO 930
C
C CHECK FOR FILE START AFTER CORE START
C
      IF (JBEGDT .LT. JSCRTC(3)) GO TO 932
      IF (JBEGDT .EQ. JSCRTC(3) .AND. BEGTIM .LT. RSCRTC(5)) GO TO 934
C
C CHECK FOR FILE STOP BEFORE CORE STOP
C
      IF (JENDDT .GT. JSCRTC(4)) GO TO 936
      IF (JBEGDT .EQ. JSCRTC(4) .AND. ENDTIM .GT. RSCRTC(6)) GO TO 938
C
C READ THE FILE REGION
C
      CALL FLRGRD(IPRINT, INFILE, JSCRTC(1), JSCRTC(2), JSCRTC(3),
     $      JSCRTC(4), JSCRTC(5), JSCRTC(6), RSCRTC(7), RSCRTC(8),
     $      RSCRTC(9), RSCRTC(10),RSCRTC(11), RSCRTC(12), RSCRTC(13),
     $      RSCRTC(14), RSCRTC(15), JFLAG)
      IF (JFLAG .LT. 0) GO TO 942
C
C CHECK UTM ORIGIN
C
      IF (JUTMZN .NE. JSCRTC( 6)) GO TO  944
      IF (XUTMOR .NE. RSCRTC( 7)) GO TO  946
      IF (YUTMOR .NE. RSCRTC( 8)) GO TO  948
C
C CHECK REGION ORIGIN
C
      IF (XREGOR .NE. RSCRTC( 9)) GO TO 950
      IF (YREGOR .NE. RSCRTC(10)) GO TO 952
C
C CHECK CELL SIZE
C
      IF (XCELLD .NE. RSCRTC(11)) GO TO 954
      IF (YCELLD .NE. RSCRTC(12)) GO TO 956
C
C CHECK NUMBER OF HORIZONTAL CELLS AND PRESENCE OF VERTICAL
C
      IF (NXCELL .NE. JSCRTC( 1)) GO TO 958
      IF (NYCELL .NE. JSCRTC( 2)) GO TO 960
      IF (NZCELL .EQ. 0 .OR. JSCRTC(3) .EQ. 0) GO TO 305
C
C CHECK VERTICAL CELL COUNTS
C
      IF (NZCELL .NE. JSCRTC( 3)) GO TO 962
      IF (NZLOWR .NE. JSCRTC( 4)) GO TO 964
      IF (NZUPPR .NE. JSCRTC( 5)) GO TO 966
C
C CHECK SURFACE LAYER HEIGHT AND LAYER MINIMA
C
      IF (ZHTSUR .NE. RSCRTC(13)) GO TO 968
      IF (ZMINLW .NE. RSCRTC(14)) GO TO 970
      IF (ZMINUP .NE. RSCRTC(15)) GO TO 972
C
C CHECK FOR PRESENCE OF SEGMENT DEFINITION RECORD -- IF SO, READ IT
C
  305 IF (NSGLOC .LE. 0) GO TO 405
      CALL FLSGRD(IPRINT, INFILE, NSGLOC, JSCRTC(1), JSCRTC(NSGLOC + 1),
     $     JSCRTC(2 * NSGLOC + 1), JSCRTC(3* NSGLOC + 1), JFLAG)
      IF (JFLAG .LT. 0) GO TO 982
C
C CHECK FOR NEED TO COMPARE -- IF SO, SET LOOP OVER SEGMENTS
C
      IF (NSGMNT .LE. 0) GO TO 405
      DO 320 K=1,NSGMNT
         KSGMT = K
C
C COMPARE SEGMENT ORIGINS
C
         IF (JXSGOR(K) .NE. JSCRTC(K)) GO TO 984
         IF (JYSGOR(K) .NE. JSCRTC(NSGLOC + K)) GO TO 986
C
C COMPARE SEGMENT SIZES
C
         IF (NXSGCL(K) .NE. JSCRTC(2 * NSGLOC + K)) GO TO 988
         IF (NYSGCL(K) .NE. JSCRTC(3 * NSGLOC + K)) GO TO 990
C
C END LOOP
C
  320 CONTINUE
C
C CHECK FOR PRESENCE OF SPECIES NAME RECORD -- IF SO, READ IT
C
  405 IF (NSPLOC .LE. 0) GO TO 1000
      CALL FLSPRD(IPRINT, INFILE, NAMLEN, NSPLOC, JSCRTC(1), JFLAG)
      IF (JFLAG .LT. 0) GO TO 994
C
C CHECK FOR NEED TO COMPARE -- IF SO, SET LOOP OVER SPECIES
C
      IF (NSPECS .LE. 0) GO TO 1000
      DO 420 K=1,NSPECS
         KSPCS = K
C
C CALCULATE LOCAL INDEX AND COMPARE NAMES
C
         KINDX = (K-1) * NAMLEN + 1
         CALL COMPAR(IPRINT, NAMLEN, MSPECS(1,K), JSCRTC(KINDX), JFLAG)
         IF (JFLAG .NE. 1) GO TO 998
C
C END LOOP AND RETURN TO CALLER
C
  420 CONTINUE
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  902 WRITE (IPRINT, 2902) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NONPOSITIVE FILE IDENTIFICATION LENGTH
C
  904 WRITE (IPRINT, 2904) NIDLEN
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH FOR FIRST RECORD
C
  906 WRITE (IPRINT, 2906) NSCRTC, NFIRST
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH FOR SECOND RECORD
C
  908 WRITE (IPRINT, 2908) NSCRTC, NSECND
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH FOR THIRD RECORD
C
  910 WRITE (IPRINT, 2910) NSCRTC, NSPECS, NAMLEN
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH FOR FOURTH RECORD
C
  912 WRITE (IPRINT, 2912) NSCRTC, NSGMNT, NSGLEN
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILE HEADER READ
C
  922 WRITE (IPRINT, 2922) JFLAG
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH OF FILE NAME
C
  926 NAMEND = NAMLEN + 6
      WRITE (IPRINT, 2926) INFILE, (JSCRTC(I),I=7,NAMEND), MFILNM
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN SEGMENT COUNT
C
  928 WRITE (IPRINT, 2928) INFILE, NSGLOC, NSGMNT
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN SPECIES COUNT
C
  930 WRITE (IPRINT, 2930) INFILE, NSPLOC, NSPECS
      JFLAG = -15
      GO TO 1000
C
C ERROR MESSAGE FOR LATE START DATE
C
  932 WRITE (IPRINT, 2932) INFILE, JSCRTC(3), JBEGDT
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR LATE START TIME
C
  934 WRITE (IPRINT, 2934) INFILE, RSCRTC(5), BEGTIM
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR EARLY END DATE
C
  936 WRITE (IPRINT, 2936) INFILE, JSCRTC(4), JENDDT
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR EARLY END TIME
C
  938 WRITE (IPRINT, 2938) INFILE, RSCRTC(6), ENDTIM
      JFLAG = -19
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILE REGION READ
C
  942 WRITE (IPRINT, 2942) JFLAG
      JFLAG = -21
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN MISMATCH IN UTM ZONE NUMBER
C
  944 WRITE (IPRINT, 2944) INFILE, JSCRTC( 6), JUTMZN
      JFLAG = -22
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN UTM ORIGIN X-VALUE
C
  946 WRITE (IPRINT, 2946) INFILE, RSCRTC( 7), XUTMOR
      JFLAG = -23
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN UTM ORIGIN Y-VALUE
C
  948 WRITE (IPRINT, 2948) INFILE, RSCRTC( 8), YUTMOR
      JFLAG = -24
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN REGION ORIGIN X-VALUE
C
  950 WRITE (IPRINT, 2950) INFILE, RSCRTC( 9), XREGOR
      JFLAG = -25
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN REGION ORIGIN Y-VALUE
C
  952 WRITE (IPRINT, 2952) INFILE, RSCRTC(10), YREGOR
      JFLAG = -26
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN CELL SIZE X-VALUE
C
  954 WRITE (IPRINT, 2954) INFILE, RSCRTC(11), XCELLD
      JFLAG = -27
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN CELL SIZE Y-VALUE
C
  956 WRITE (IPRINT, 2956) INFILE, RSCRTC(12), YCELLD
      JFLAG = -28
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF X-CELLS
C
  958 WRITE (IPRINT, 2958) INFILE, JSCRTC( 1), NXCELL
      JFLAG = -29
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF Y-CELLS
C
  960 WRITE (IPRINT, 2960) INFILE, JSCRTC( 2), NYCELL
      JFLAG = -30
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF Z-CELLS
C
  962 WRITE (IPRINT, 2962) INFILE, JSCRTC( 3), NZCELL
      JFLAG = -31
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF LOWER Z-CELLS
C
  964 WRITE (IPRINT, 2964) INFILE, JSCRTC( 4), NZLOWR
      JFLAG = -32
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF UPPER Z-CELLS
C
  966 WRITE (IPRINT, 2966) INFILE, JSCRTC( 5), NZUPPR
      JFLAG = -33
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN HEIGHT OF SURFACE LAYER
C
  968 WRITE (IPRINT, 2968) INFILE, RSCRTC(13), ZHTSUR
      JFLAG = -34
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN HEIGHT OF UPPER LAYER
C
  970 WRITE (IPRINT, 2970) INFILE, RSCRTC(14), ZMINLW
      JFLAG = -35
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN HEIGHT OF UPPER LAYER
C
  972 WRITE (IPRINT, 2972) INFILE, RSCRTC(15), ZMINUP
      JFLAG = -36
      GO TO 1000
C
C ERROR MESSAGE FOR  ERROR IN FILE SEGMENTATION READ
C
  982 WRITE (IPRINT, 2982) INFILE, JFLAG
      JFLAG = -41
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN SEGMENT ORIGIN X-CELL
C
  984 WRITE (IPRINT, 2984) INFILE, JSCRTC(KSGMT), JXSGOR(KSGMT)
      JFLAG = -42
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN SEGMENT ORIGIN Y-CELL
C
  986 WRITE (IPRINT, 2986) INFILE, JSCRTC(NSGLOC+KSGMT), JYSGOR(KSGMT)
      JFLAG = -43
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF SEGMENT X-CELLS
C
  988 WRITE (IPRINT, 2988) INFILE, JSCRTC(2*NSGLOC+KSGMT), NXSGCL(KSGMT)
      JFLAG = -44
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN NUMBER OF SEGMENT Y-CELLS
C
  990 WRITE (IPRINT, 2990) INFILE, JSCRTC(3*NSGLOC+KSGMT), NYSGCL(KSGMT)
      JFLAG = -45
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILE SPECIES READ
C
  994 WRITE (IPRINT, 2994) INFILE, JFLAG
      JFLAG = -47
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH IN SPECIES NAME
C
  998 KEND = KINDX + NAMLEN - 1
      WRITE (IPRINT, 2998) INFILE, (JSCRTC(I), I=KINDX, KEND),
     $                     (MSPECS(I,KSPCS), I=1, NAMLEN)
      JFLAG = -49
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2902 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FILVER CALLED WITH NAME LENGTH OF , I10)
 2904 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FILVER CALLED WITH FILE ID LENGTH OF,I10)
 2906 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FILVER CALLED WITH SCRATCH LENGTH OF , I10,
     $        //, 45H FIRST HEADER RECORD NEEDS SCRATCH LENGTH OF , I10)
 2908 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FILVER CALLED WITH SCRATCH LENGTH OF , I10,
     $        //, 46H SECOND HEADER RECORD NEEDS SCRATCH LENGTH OF ,I10)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FILVER CALLED WITH SCRATCH LENGTH OF , I10,
     $        //, 45H THIRD HEADER RECORD NEEDS SCRATCH LENGTH OF , I10,
     $        7H TIMES, I10)
 2912 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FILVER CALLED WITH SCRATCH LENGTH OF , I10,
     $        //, 46H FOURTH HEADER RECORD NEEDS SCRATCH LENGTH OF ,I10,
     $        7H TIMES, I10)
 2922 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO FILVER FROM SUBROUTINE FLHDRD ,  //)
 2926 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 20H CONTAINS FILE NAME , 10A1, //,
     $        27H THE EXPECTED FILE NAME IS , 10A1, 2H. )
 2928 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS SEGMENT COUNT , I10, //,
     $        31H THE EXPECTED SEGMENT COUNT IS , I10, 2H. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2930 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS SPECIES COUNT , I10, //,
     $        31H THE EXPECTED SPECIES COUNT IS , I10, 2H. )
 2932 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS STARTING DATE , I10, //,
     $        31H THE EXPECTED STARTING DATE IS , I10, 2H. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2934 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS STARTING TIME , F10.2, //,
     $        31H THE EXPECTED STARTING TIME IS , F10.2, 2H. )
 2936 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS STOPPING DATE , I10, //,
     $        31H THE EXPECTED STOPPING DATE IS , I10, 2H. )
 2938 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 24H CONTAINS STOPPING TIME , F10.2, //,
     $        31H THE EXPECTED STOPPING TIME IS , F10.2, 2H. )
 2942 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO FILVER FROM SUBROUTINE FLRGRD , //)
 2944 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 26H CONTAINS UTM ZONE NUMBER , I10, //,
     $        33H THE EXPECTED UTM ZONE NUMBER IS , I10, 2H. )
 2946 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 29H CONTAINS UTM ORIGIN X-VALUE , F10.2, //,
     $        36H THE EXPECTED UTM ORIGIN X-VALUE IS , F10.2, 2H. )
 2948 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 29H CONTAINS UTM ORIGIN Y-VALUE , 10A1, //,
     $        36H THE EXPECTED UTM ORIGIN Y-VALUE IS , 10A1, 2H. )
 2950 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS REGION ORIGIN X-VALUE , F10.2, //,
     $        39H THE EXPECTED REGION ORIGIN X-VALUE IS , F10.2, 2H. )
 2952 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS REGION ORIGIN Y-VALUE , F10.2, //,
     $        39H THE EXPECTED REGION ORIGIN Y-VALUE IS , F10.2, 2H. )
 2954 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 28H CONTAINS CELL SIZE X-VALUE , F10.2, //,
     $        35H THE EXPECTED CELL SIZE X-VALUE IS , F10.2, 2H. )
 2956 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 28H CONTAINS CELL SIZE Y-VALUE , F10.2, //,
     $        35H THE EXPECTED CELL SIZE Y-VALUE IS , F10.2, 2H. )
 2958 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 28H CONTAINS NUMBER OF X-CELLS , I10, //,
     $        35H THE EXPECTED NUMBER OF X-CELLS IS , I10, 2H. )
 2960 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 28H CONTAINS NUMBER OF Y-CELLS , I10, //,
     $        35H THE EXPECTED NUMBER OF Y-CELLS IS , I10, 2H. )
 2962 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 28H CONTAINS NUMBER OF Z-CELLS , I10, //,
     $        35H THE EXPECTED NUMBER OF Z-CELLS IS , I10, 2H. )
 2964 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 40H CONTAINS NUMBER OF LOWER LAYER Z-CELLS ,
     $        I10, //,
     $        47H THE EXPECTED NUMBER OF LOWER LAYER Z-CELLS IS ,
     $        I10, 2H. )
 2966 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 40H CONTAINS NUMBER OF UPPER LAYER Z-CELLS ,
     $        I10, //,
     $        47H THE EXPECTED NUMBER OF UPPER LAYER Z-CELLS IS ,
     $        I10, 2H. )
 2968 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 36H CONTAINS HEIGHT OF SURFACE LAYER , F10.2, //,
     $        41H THE EXPECTED HEIGHT OF SURFACE LAYER IS , F10.2, 2H. )
 2970 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS HEIGHT OF LOWER LAYER , F10.2, //,
     $        39H THE EXPECTED HEIGHT OF LOWER LAYER IS , F10.2, 2H. )
 2972 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS HEIGHT OF UPPER LAYER , F10.2, //,
     $        39H THE EXPECTED HEIGHT OF UPPER LAYER IS , F10.2, 2H. )
 2982 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO FILVER FROM SUBROUTINE FLSGRD , //)
 2984 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS SEGMENT ORIGIN X-CELL , I10, //,
     $        39H THE EXPECTED SEGMENT ORIGIN X-CELL IS , I10, 2H. )
 2986 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 32H CONTAINS SEGMENT ORIGIN Y-CELL , I10, //,
     $        39H THE EXPECTED SEGMENT ORIGIN Y-CELL IS , I10, 2H. )
 2988 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 36H CONTAINS NUMBER OF SEGMENT X-CELLS , I10, //,
     $        43H THE EXPECTED NUMBER OF SEGMENT X-CELLS IS , I10, 2H. )
 2990 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 36H CONTAINS NUMBER OF SEGMENT Y-CELLS , I10, //,
     $        43H THE EXPECTED NUMBER OF SEGMENT Y-CELLS IS , I10, 2H. )
 2994 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO FILVER FROM SUBROUTINE FLSPRD , //)
 2998 FORMAT (1H1, 46H****** INPUT FILE MISMATCH ****** FILE NUMBER ,
     $        I10, 23H CONTAINS SPECIES NAME , 10A1, //,
     $        30H THE EXPECTED SPECIES NAME IS , 10A1, 2H. )
      END
