      SUBROUTINE HTPRRD(IPRINT, INFILE, NXCELL,
     $    NYCELL, NZCELL, JCURDT, CURTIM, OUTMAT, JFLAG)
C
C NAME -- HEIGHT/PRESSURE FILE READ
C
C DESCRIPTION -- READS THE TIME-VARIANT HEIGHT/PRESSURE FILE RECORD
C                WHEN TIME UPDATE IS NEEDED
C                (NOTE:  PRESSURE DATA IS NOT CURRENTLY SAVED)
C
C PROGRAMMER -- TC MYERS /SAI DECEMBER 1996
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         NZCELL    I  NUMBER OF LAYERS 
C         JCURDT    I  CURRENT DATE
C         CURTIM    R  CURRENT TIME
C
C OUTPUTS --
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         JSTRDT    I  STARTING DATE FOR CURRENT RECORD
C         JSTPDT    I  STOPPING DATE FOR CURRENT RECORD
C         STRTIM    R  STARTING TIME FOR CURRENT RECORD
C         STPTIM    R  STOPPING TIME FOR CURRENT RECORD
C
C ROUTINES CALLED --
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         CALTOJ    CONVERTS CALENDAR DATE TO JULIAN DATE
C
C ERROR CONDITIONS --
C         -1        ERROR ON FILE DATE/TIME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION OUTMAT(NXCELL, NYCELL, NZCELL)
C
C INITIALIZE DATE AND TIME VALUES
C
      DATA JSTRDT /0/
      DATA JSTPDT /0/
      DATA STRTIM /0.0/
      DATA STPTIM /0.0/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C
C TEST DATE AND TIME FOR BEING IN CURRENT SPAN
C
105   CONTINUE
      IF(CURTIM.GE.STRTIM+24.*FLOAT(JSTRDT-JCURDT).AND.
     $CURTIM.LT.STPTIM+24.*FLOAT(JSTPDT-JCURDT)) GO TO 1000
C
C TEST DATE AND TIME FOR BEING PRIOR TO CURRENT SPAN
C
      IF (JCURDT .LT. JSTRDT) GO TO 905
      IF (JCURDT .EQ. JSTRDT .AND. CURTIM .LT. STRTIM) GO TO 905
C
C LOOP OVER LEVELS AND READ DATA RECORDS
C
      DO 110 K=1,NZCELL
        READ(INFILE) STRTIM, JIN, 
     $               ((OUTMAT(I,J,K),I=1,NXCELL),J=1,NYCELL)
        READ(INFILE) STDUM, JDUMDT, 
     $               ((PRDUM,I=1,NXCELL),J=1,NYCELL)
  110 CONTINUE
C
C  CONVERT DATE AND TIME TO PROPER FORMAT
C  MAKE END TIME ONE HOUR AFTER START TIME
C
      STRTIM = STRTIM/100.
      IF (JIN .GT. 99999) THEN 
        CALL CALTOJ(JIN, JSTRDT) 
      ELSE
        JSTRDT = JIN
      ENDIF
      STPTIM = STRTIM + 1.
      JSTPDT = JSTRDT
      WRITE (IPRINT, 2110) JSTRDT, STRTIM, INFILE
C
C GO BACK TO TIME TEST
C
      GO TO 105
C
C ERROR MESSAGE FOR TIME PRIOR TO CURRENT
C
  905 WRITE (IPRINT, 2905) JCURDT, CURTIM, JSTRDT, STRTIM
      JFLAG = -1
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2110 FORMAT (/, ' READ INTERVAL ', I10, F6.2, ' ON UNIT ', I6)
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H THE CURRENT DATE , I10, 10H AND TIME , F10.2, //,
     $        28H ARE PRIOR TO THE FILE DATE , I10, 10H AND TIME ,F10.2,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
