      SUBROUTINE MTSCRD(IPRINT, INFILE, NAMLEN, NVARBL,
     $    JCURDT, CURTIM, MVARBL, MVARNM, OUTMAT, JFLAG)
C
C NAME -- METEOROLOGICAL SCALARS FILE READ
C
C DESCRIPTION -- READS THE TIME-VARIANT METEOROLOGICAL SCALARS FILE RECORD
C                WHEN TIME UPDATE IS NEEDED
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES TO BE READ
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         JCURDT    I  CURRENT DATE
C         CURTIM    R  CURRENT TIME
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         MVARNM    I  FILE VARIABLE NAME
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         KVRBL     I  VARIABLE NUMBER
C         JSTRDT    I  STARTING DATE FOR CURRENT RECORD
C         JSTPDT    I  STOPPING DATE FOR CURRENT RECORD
C         STRTIM    R  STARTING TIME FOR CURRENT RECORD
C         STPTIM    R  STOPPING TIME FOR CURRENT RECORD
C
C ROUTINES CALLED --
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         FLMSRD    READS A METEOROLOGICAL SCALARS RECORD
C         FLTMRD    READS A TIME SPAN RECORD
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        ERROR IN FILE TIME READ
C         -3        ERROR IN FILE RECORD READ
C         -4        MISMATCH ON SEGMENT NUMBER
C         -5        ERROR IN VARIABLE NAME COMPARISON ROUTINE
C         -6        MISMATCH ON VARIABLE NAME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN, NVARBL)
      character*4 MVARBL(NAMLEN, NVARBL)
Ctcm  DIMENSION MVARNM(NAMLEN, NVARBL)
      character*4 MVARNM(NAMLEN, NVARBL)
      DIMENSION OUTMAT(NVARBL)
C
C INITIALIZE DATE AND TIME VALUES
C
      DATA JSTRDT /0/
      DATA JSTPDT /0/
      DATA STRTIM /0.0/
      DATA STPTIM /0.0/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C
C TEST DATE AND TIME FOR BEING IN CURRENT SPAN
C
 105  IF(CURTIM.GE.STRTIM+24.*FLOAT(JSTRDT-JCURDT).AND.
     $CURTIM.LT.STPTIM+24.*FLOAT(JSTPDT-JCURDT)) GO TO 1000
C
C TEST DATE AND TIME FOR BEING PRIOR TO CURRENT SPAN
C
      IF (JCURDT .LT. JSTRDT) GO TO 905
      IF (JCURDT .EQ. JSTRDT .AND. CURTIM .LT. STRTIM) GO TO 905
C
C READ NEXT DATE AND TIME
C
      CALL FLTMRD(IPRINT, INFILE, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 910
C
C READ THE NEXT FILE RECORD
C
      CALL FLMSRD(IPRINT, INFILE, NAMLEN, NVARBL,
     $     MVARNM, OUTMAT, JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C SET LOOP FOR VARIABLE NAMES
C
      DO 110 J = 1,NVARBL
C
C CHECK THE FILE NAME AGAINST THE INPUT NAME
C
         CALL COMPAR(IPRINT, NAMLEN, MVARBL(1,J), MVARNM(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 925
         IF (JFLAG .EQ. 1) GO TO 110
         KVRBL = J
         GO TO 930
C
C END LOOP AND GO BACK TO TIME TEST
C
  110 CONTINUE
      GO TO 105
C
C ERROR MESSAGE FOR TIME PRIOR TO CURRENT
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE TIME READ
C
  910 WRITE (IPRINT, 2910) JFLAG
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE RECORD READ
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON VARIABLE NAMES COMPARISON
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON VARIABLE NAME
C
  930 WRITE (IPRINT, 2930) (MVARNM(I,KVRBL), I = 1,NAMLEN),
     $                     (MVARBL(I,KVRBL), I = 1,NAMLEN)
      JFLAG = -6
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H THE CURRENT DATE , I10, 10H AND TIME , F10.2, //,
     $        28H ARE PRIOR TO THE FILE DATE , I10, 10H AND TIME ,F10.2,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT(26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURN TO MTSCRD FROM SUBROUTINE FLTMRD , //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURNED TO MTSCRD FROM SUBROUTINE FLMSRD , //)
 2925 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURND TO MTSCRD FROM SUBROUTINE COMPAR , //)
 2930 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        24H THE FILE VARIABLE NAME , 10A1, //,
     $        42H DOES NOT MATCH THE CURRENT VARIABLE NAME , 10A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
