      SUBROUTINE REGNRD (INCARD,IPRINT,NXCELL,NYCELL,NZCELL,NZLOWR,
     $  NZUPPR,JUTMZN,XUTMOR,YUTMOR,XREGOR,YREGOR,XCELLD,YCELLD,ZHTSUR,
     $  ZMINLW,ZMINUP,JFLAG)
C
C NAME -- REGION PACKET READ
C
C DESCRIPTION -- READS THE REGION PACKET THAT APPEARS AT THE
C         BEGINNING OF EVERY PROGRAM THAT WRITES A FILE
C
C PROGRAMMER -- GW LUNDBERG/SAI  MAY 1977
C
C MODIFIER   -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C
C OUTPUTS --
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL    I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR    I  NUMBER OF CELLS IN LOWER VERTICAL LAYER
C         NZUPPR    I  NUMBER OF CELLS IN UPPER VERTICAL LAYER
C         JUTMZN    I  UTM ZONE NUMBER
C         XUTMOR    R  X-COORDINATE OF UTM ORIGIN
C         YUTMOR    R  Y-COORDINATE OF UTM ORIGIN
C         XREGOR    R  X-COORDINATE OF REGION ORIGIN
C         YREGOR    R  Y-COORDINATE OF REGION ORIGIN
C         XCELLD    R  LENGTH OF GRID CELL IN X-DIRECTION
C         YCELLD    R  LENGTH OF GRID CELL IN Y-DIRECTION
C         ZHTSUR    R  CELL HEIGHT OF SURFACE LAYER
C         ZMINLW    R  MINIMUM CELL HEIGHT, LOWER LAYER
C         ZMINUP    R  MINIMUM CELL HEIGHT, UPPER LAYER
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NRGION    I  NUMBER OF WORDS IN PACKET HEADER
C         NENDRG    I  NUMBER OF WORDS IN PACKET TRAILER
C         NINWRD    I  NUMBER OF WORDS IN INPUT LINE
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         MRGION    I  PACKET HEADER NAME
C         MENDRG    I  PACKET TRAILER NAME
C         MINWRD    I  INPUT LINE
C         MCRDID    I  CARD IDENTIFICATION
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C
C ERROR CONDITIONS --
C         -3        MISMATCH IN NAME OF PACKET HEADER
C         -4        NON-POSITIVE CELL DIMENSIONS
C         -5        NON-POSITIVE NUMBER OF CELLS
C         -8        MISMATCH IN TOTAL NUMBER OF Z-CELLS, NO SURFACE LAYER
C         -9        MISMATCH IN TOTAL NUMBER OF Z-CELLS
C         -12       MISMATCH IN NAME OF PACKET TRAILER
C
C OTHER INFORMATION --
C
C
C SET DIMENSION OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MRGION(6), MENDRG(3), MINWRD(60), MCRDID(20)
      character*4 MRGION(6), MENDRG(3), MINWRD(60), MCRDID(20)
C
C DECLARE PACKET HEADER AND TRAILER
C
      DATA MRGION /'R', 'E', 'G', 'I', 'O', 'N'/
      DATA MENDRG /'E', 'N', 'D'/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA NRGION /6/
      DATA NENDRG /3/
      DATA NINWRD /60/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND PRINT THE PACKET NAME CARD
C
      READ (INCARD, 1003) MINWRD, MCRDID
      WRITE(IPRINT, 2003) MINWRD, MCRDID
C
C PACK THE PACKET NAME
C
      CALL TXTPAK(IPRINT, NINWRD ,MINWRD, NPACKD, JFLAG)
C
C VERIFY THAT IT IS CORRECT
C
      CALL COMPAR(IPRINT, NRGION, MRGION, MINWRD, JFLAG)
      IF (JFLAG .NE. 1) GO TO 915
C
C READ AND PRINT UTM COORDINATES AND ZONE NUMBER
C
      READ (INCARD, 1005) XUTMOR, YUTMOR, JUTMZN, MCRDID
      WRITE(IPRINT, 2005) XUTMOR, YUTMOR, JUTMZN, MCRDID
C
C READ AND PRINT REGION ORGIN
C
      READ (INCARD, 1010) XREGOR, YREGOR, MCRDID
      WRITE(IPRINT, 2010) XREGOR, YREGOR, MCRDID
C
C READ AND PRINT DIMENSIONS OF GRID CELL
C
      READ (INCARD, 1015) XCELLD, YCELLD, MCRDID
      WRITE(IPRINT, 2015) XCELLD, YCELLD, MCRDID
C
C CHECK DIMENSIONS FOR POSITIVE VALUE
C
      IF (XCELLD .LE. 0.0) GO TO 920
      IF (YCELLD .LE. 0.0) GO TO 920
C
C READ AND PRINT NUMBER OF GRID CELLS
C
      READ (INCARD, 1020) NXCELL, NYCELL, NZCELL, MCRDID
      WRITE(IPRINT, 2020) NXCELL, NYCELL, NZCELL, MCRDID
C
C CHECK NUMBER OF CELLS FOR POSITIVE VALUE
C
      IF (NXCELL .LE. 0) GO TO 925
C
C READ AND PRINT VERTICAL DEFINITIONS
C
      READ (INCARD, 1025) NZLOWR, NZUPPR, ZHTSUR, ZMINLW, ZMINUP, MCRDID
      WRITE(IPRINT, 2025) NZLOWR, NZUPPR, ZHTSUR, ZMINLW, ZMINUP, MCRDID
C
C       IF NO VERTICAL VALUES, DO NOT CHECK THEM
C
       GO TO 200
C
C VERIFY THE CELL HEIGHTS AND CELL COUNT
C
C***********************************************************************
C
C    THE FOLLOWING STATEMENT INSERTED TO ELIMINATE THE 'NO PATH' CONDITION
C    DETECTED BY THE PR1ME COMPILER
C***********************************************************************
99999 CONTINUE
      IF (ZHTSUR .LE. 0.0 .AND. NZCELL .NE. NZLOWR + NZUPPR) GO TO 940
      IF (ZHTSUR .GT. 0.0 .AND. NZCELL .NE. NZLOWR + NZUPPR + 1)
     $    GO TO 945
C
C READ AND PRINT THE PACKET END CARD
C
  200  CONTINUE
      READ (INCARD, 1003) MINWRD, MCRDID
      WRITE(IPRINT, 2003) MINWRD, MCRDID
C
C PACK THE PACKET END
C
      CALL TXTPAK(IPRINT, NINWRD, MINWRD, NPACKD, JFLAG)
C
C VERIFY THAT IT IS CORRECT
C
      CALL COMPAR(IPRINT, NENDRG, MENDRG, MINWRD, JFLAG)
      IF (JFLAG .NE. 1) GO TO 960
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON PACKET HEADER
C
  915 WRITE (IPRINT, 2915) MINWRD, MRGION
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE CELL DIMENSIONS
C
  920 WRITE (IPRINT, 2920) XCELLD, YCELLD
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF CELLS
C
  925 WRITE (IPRINT, 2925) NXCELL, NYCELL
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON VERTICAL CELL COUNT, NO SURFACE LAYER
C
  940 WRITE (IPRINT, 2940) NZCELL, NZUPPR, NZLOWR
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON VERTICAL CELL COUNT
C
  945 WRITE (IPRINT, 2945) NZCELL, NZLOWR, NZUPPR
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON PACKET TRAILER
C
  960 WRITE (IPRINT, 2960) MINWRD, MENDRG
      JFLAG = -12
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1003 FORMAT (60A1, 20A1)
 1005 FORMAT (2F10.0, I10, 30X, 20A1)
 1010 FORMAT (2F10.0, 40X, 20A1)
 1015 FORMAT (2F10.0, 40X, 20A1)
 1020 FORMAT (3I10, 30X, 20A1)
 1025 FORMAT (2I10, 3F10.0, 10X, 20A1)
 2003 FORMAT (1X, 60A1, 20A1)
 2005 FORMAT (1X, 2F10.0, I10, 30X, 20A1)
 2010 FORMAT (1X, 2F10.0, 40X, 20A1)
 2015 FORMAT (1X, 2F10.2, 40X, 20A1)
 2020 FORMAT (1X, 3I10, 30X, 20A1)
 2025 FORMAT (1X, 2I10, 3F10.2, 10X, 20A1)
 2915 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        40H MISMATCH BETWEEN THE INPUT PACKET NAME , 10A1, //,
     $        29H AND THE EXPECTED PACKET NAME, 7A1,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2920 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******, /,
     $        31H VALUES FOR THE CELL DIMENSIONS, F10.2, 5H AND , F10.2,
     $        17H MUST BE POSITIVE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2925 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******, /,
     $        32H VALUES FOR THE REGION DIMENSION, I2, 5H AND , I2,
     $        17H MUST BE POSITIVE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2940 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******, /,
     $        33H THE NUMBER OF VERTICAL CELLS IS , I10, //,
     $        42H THIS VALUE DOES NOT MATCH THE SUM OF THE ,
     $        28H NUMBER OF LOWER LAYER CELLS , I10,
     $        24H PLUS UPPER LAYER CELLS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2945 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******, /,
     $        33H THE NUMBER OF VERTICAL CELLS IS , I10, //,
     $        42H THIS VALUE DOES NOT MATCH THE SUM OF THE ,
     $        28H NUMBER OF LOWER LAYER CELLS , I10,
     $        24H PLUS UPPER LAYER CELLS , I10, 7H PLUS 1, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2960 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******, /,
     $        44H MISMATCH BETWEEN THE INPUT PACKET END CARD , 3A1,
     $        //, 34H AND THE EXPECTED PACKET END CARD , 3A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
