      SUBROUTINE SBRGRD (INCARD, IPRINT, NAMLEN, NIDLEN, NSBRGN, NXCELL,
     $                   NYCELL, LINPTP, LSBRGP, JBEGDT, JENDDT, BEGTIM,
     $                   ENDTIM, MFILNM, MFILID, MSBRGN, JRGRID, JFLAG)
C
C NAME -- SUBREGION PACKET READ
C
C DESCRIPTION -- READS THE SUBREGIONS PACKET AS PART OF TIME-VARIANT
C                DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NIDLEN    I  NUMBER OF WORDS IN FILE IDENTIFICATION
C         NTIMES    I  NUMBER OF TIMES TO REPEAT SUBREGION DESIGNATION
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         LINPTP    I  INPUT PRINT FLAG
C         LSBRGP    I  REGIONAL GRID PRINT FLAG
C         JBEGDT    I  BEGINNING DATE
C         JENDDT    I  ENDING DATE
C         BEGTIM    R  BEGINNING TIME
C         ENDTIM    R  ENDING TIME
C         MFILNM    I  NAME OF FILE BEING CREATED
C         MFILID    I  IDENTIFICATION OF FILE BEING CREATED
C
C OUTPUTS --
C         MSBRGN    I  SUBREGION NAMES
C         JRGRID    I  REGIONAL GRID
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         NTILEN    I  NUMBER OF WORDS IN TITLE
C         NWORDS    I  NUMBER OF WORDS TO BE SET
C         KCOLN     I  POINTER TO COLUMN NUMBER
C         KROWN     I  POINTER TO ROW NUMBER
C         KLAST     I  POINTER TO LAST POSITION IN ROW
C         KSBRG     I  POINTER TO SUBREGION NAME
C         KFRMT     I  POINTER TO FORMAT NUMBER
C         KZCLL     I  POINTER TO CURRENT Z-LEVEL
C         MENDSB    I  PACKET TRAILER NAME
C         MBLANK    I  BLANK CHARACTER
C         MCRDID    I  CARD IDENTIFICATION
C         MTITLE    I  TITLE OF OUTPUT GRID
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         SINVAL    INSERTS SINGLE VALUE INTO ARRAY
C         GRIDPR    PRINTS 2-DIMENSIONAL GRID
C
C ERROR CONDITIONS --
C         -6        BLANK NAME
C         -9        NO SPACE FOR NEW SUBREGION NAME
C         -10       NON-POSITIVE ROW NUMBER
C         -11       NON-POSITIVE COLUMN NUMBER
C         -12       TOO MANY ROW ENTRIES
C         -14       ERROR FROM GRIDPR
C         -15       MISSING SUBREGIONS
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LSBRGP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MSBRGN(NAMLEN,NSBRGN)
      character*4 MSBRGN(NAMLEN,NSBRGN)
      DIMENSION JRGRID(NXCELL,NYCELL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MSBRNM(10), MENDSB(10), MCRDID(20), MTITLE(60)
      character*4 MSBRNM(10), MENDSB(10), MCRDID(20), MTITLE(60)
      character*4 MBLANK
C
C DECLARE PACKET TRAILER AND TITLE
C
      DATA MENDSB /'E', 'N', 'D', 7*' '/
      DATA MTITLE /16 * ' ', 'R', 'E', 'G', 'I', 'O', 'N', 'A', 'L',
     $             ' ', 'G', 'R', 'I', 'D', ' ', 'S', 'U', 'B', 'R',
     $             'E', 'G', 'I', 'O', 'N', ' ', 'M', 'A', 'P', 17*' '/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA MBLANK /' '/
      DATA KZCLL /1/
      DATA NTILEN /60/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSBRNM, KROWN, KCOLN, NTIMES, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSBRNM, KROWN, KCOLN, NTIMES,
     $                   MCRDID
C
C PACK SUBREGION NAME AND CHECK FOR BLANK
C
      CALL TXTPAK(IPRINT, NAMLEN, MSBRNM, NPACKD, JFLAG)
      IF (NPACKD .EQ. 0) GO TO 930
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MENDSB, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C SET LOOP TO FIND SUBREGION NAME
C
      DO 115 K = 1, NSBRGN
C
C COMPARE INPUT SUBREGION NAME WITH THE LIST OF SUBREGION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MSBRGN(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND SUBREGION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSBRG = K
         GO TO 140
  115 CONTINUE
C
C NAME NOT FOUND -- SET LOOP TO FIND BLANK SPOT
C
      DO 135 K = 1, NSBRGN
C
C COMPARE FIRST LETTER WITH BLANK
C
         IF (MSBRGN(1,K) .NE. MBLANK) GO TO 135
C
C FOUND ONE -- STUFF THE NAME IN HERE
C
         KSBRG = K
         DO 125 J = 1, NAMLEN
            MSBRGN(J,K) = MSBRNM(J)
C
C END LOOP AND SKIP TO ROW PROCESSING
C
  125    CONTINUE
         GO TO 140
C
C FINISH THE LOOP -- IF NO BLANKS, ERROR IN COUNT OR SPELLING
C
  135 CONTINUE
      GO TO 945
C
C CHECK THE ROW NUMBER AND THE BEGINNING COLUMN NUMBER
C
  140 IF (KROWN .LE. 0) GO TO 950
      IF (KROWN .GT. NYCELL) GO TO 950
      IF (KCOLN .LE. 0) GO TO 955
      IF (KCOLN .GT. NXCELL) GO TO 955
C
C CHECK FOR MULTI-ROW ENTRY AND, IF NECESSARY, SET FINAL COLUMN NUMBER
C
      IF (NTIMES .LT. 0) GO TO 170
      IF (NTIMES .GT. 0) GO TO 150
      KLAST = NXCELL
      GO TO 160
C
C CALCULATE AND CHECK THE FINAL COLUMN NUMBER
C
  150 KLAST = KCOLN + NTIMES - 1
      IF (KLAST .LT. KCOLN) GO TO 960
      IF (KLAST .GT. NXCELL) GO TO 960
C
C SET LOOP TO STORE THIS SUBREGION NUMBER IN THE GRID
C
  160 DO 165 J = KCOLN, KLAST
         JRGRID(J,KROWN) = KSBRG
C
C END LOOP AND READ NEXT CARD
C
  165 CONTINUE
      GO TO 105
C
C CALCULATE THE NUMBER OF WORDS TO END OF GRID AND SET VALUE
C
  170 NWORDS = NXCELL*NYCELL - NXCELL*(KROWN - 1) - KCOLN + 1
      CALL SINVAL(IPRINT, NWORDS, KSBRG, JRGRID(KCOLN, KROWN), JFLAG)
C
C GET NEXT CARD
C
      GO TO 105
C
C END OF PACKET, PRINT SUBREGIONS GRID IF WANTED
C
  210 IF (.NOT. LSBRGP) GO TO 220
C
C PRINT THE SUBREGION GRID IN I5 FORMAT
C
      KFRMT = 231
      KTYPE = KFRMT - KFRMT/10*10
      IF (KTYPE .LE. 2)
     $CALL GRIDPI(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL, NYCELL, KZCLL,
     $            KFRMT, JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILNM, MFILID,
     $            MTITLE, JRGRID, JFLAG)
      IF (KTYPE .GT. 2)
     $CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL, NYCELL, KZCLL,
     $            KFRMT, JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILNM, MFILID,
     $            MTITLE, JRGRID, JFLAG)
      IF (JFLAG .LT. 0) GO TO 970
C
C PRINT TABLE HEADER
C
      WRITE (IPRINT, 2210)
C
C PRINT SUBREGION NAMES IN LOOP
C
      DO 215 J = 1, NSBRGN
         WRITE (IPRINT, 2215) J, (MSBRGN(I,J), I=1,NAMLEN)
  215 CONTINUE

C
C SET LOOPS TO LOOK FOR UNASSIGNED SUBREGIONS
C
  220 DO 235 J = 1, NYCELL
         DO 225 I = 1, NXCELL
C
C IF NON-POSITIVE, SET FLAG AND WRITE MESSAGE
C
            IF (JRGRID(I,J) .GT. 0) GO TO 225
            JFLAG = -15
            WRITE (IPRINT, 2220) I, J, JRGRID(I,J)
C
C END LOOPS -- IF MISSING VALUE, ERROR MESSAGE
C
  225   CONTINUE
  235 CONTINUE
      IF (JFLAG .LT. 0) GO TO 975
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK NAME
C
  930 WRITE (IPRINT, 2930)
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR NO SPACE FOR NEW SUBREGION NAME
C
  945 WRITE (IPRINT, 2945) MSBRNM
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE ROW NUMBER
C
  950 WRITE (IPRINT, 2950) KROWN, NYCELL
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE COLUMN NUMBER
C
  955 WRITE (IPRINT, 2955) KCOLN, NXCELL
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR TOO MANY ROW ENTRIES
C
  960 WRITE (IPRINT, 2960) NTIMES, NXCELL
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR FROM GRIDPR
C
  970 WRITE (IPRINT, 2970) JFLAG
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING SUBREGIONS
C
  975 WRITE (IPRINT, 2975)
      JFLAG = -15
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 3I10, 20X, 20A1)
 2105 FORMAT (1X, 10A1, 3I10, 20X, 20A1)
 2210 FORMAT (1H1, 24HSUBREGION IDENTIFICATION, ///,
     $        16H NUMBER     NAME, //)
 2215 FORMAT (1X, I5, 3X, 10A1, /)
 2220 FORMAT (25H REGIONAL GRID LOCATION (, I10, 1H,, I10,
     $        10H) CONTAINS , I10, 27H -- NOT A VALID SUBREGION., /)
 2930 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        41H BLANK SUBREGION NAMES ARE NOT ACCEPTABLE ,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2945 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        48H INSUFFICIENT SPACE IN SUBREGION NAME TABLE FOR ,
     $        10HSUBREGION , 10A1, //, 23H TOTAL SUBREGION COUNT ,
     $        46H MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        18H INPUT ROW NUMBER , I10, //,
     $        37H IS OUTSIDE THE REGION RANGE OF 1 TO , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        21H INPUT COLUMN NUMBER , I10, //,
     $        37H IS OUTSIDE THE REGION RANGE OF 1 TO , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2960 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        21H INPUT REPEAT FACTOR ,I5,16H IS NEGATIVE OR , //,
     $        36H EXTENDS BEYOND THE REGION BOUNDARY ,I5,/,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO SBRGRD FROM SUBROUTINE GRIDPR, //)
 2975 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        51H INVALID ENTRIES CITED IN ABOVE REQUIRE TERMINATION ,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
