      SUBROUTINE SCRPRT(IPRINT, NAMLEN, NINVAR, NSPECS, NUSVAR, NUNVAR,
     $  NSTATS, NPTSRC, NPTSRT, NBLINE, NSUBRG, NMETHD, NPARAM,
     $  NVMETH, NVPARM, NPRFHT, NMETSC, NSCLFT, NSCPTR, NXCELL,
     $  NYCELL, NZCELL, NINFIL, INFILE, JSCRTC, JSCPTR, NVARBL,
     $  NUNITS, JFLAG)
C
C NAME -- SCRATCH PARTITION
C
C DESCRIPTION -- DIVIDES SCRATCH AMONG THE ARRAYS REQUIRED
C                BY THE DATA PREPARATION PROGRAMS
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C MODIFICATIONS:
C
C      --  IF L3DTMP IS SET TO TRUE TO INDICATE THAT A 
C          3D TEMPERATURE FILE IS IN USE, ALLOCATE ENOUGH
C          SPACE FOR XYZ ARRAY OF TEMPS INSTEAD OF JUST XY.
C          ADDED COMMON BLOCK TMPCON TO TRANSFER FLAG.  THIS MOD IS
C          NEEDED TO ALLOW PTSRCE PROCESSOR TO USE 3D INFORMATION
C          IN CALCULATING PLUME RISE.
C          (TCM, 6/15/94)
C
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NAME LENGTH
C         NINVAR    I  NUMBER OF INTRISIC VARIABLE
C         NSPECS    I  NUMBER OF SPECIES
C         NUSVAR    I  NUMBER OF USER-DEFINED VARIABLES
C         NUNVAR    I  NUMBER OF UNIT-ONLY VARIABLES
C         NSTATS    I  NUMBER OF STATIONS
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         NPRSRT    I  NUMBER OF SOURCE TYPES
C         NBLINE    I  NUMBER OF BOUNDARY LINES
C         NSUBRG    I  NUMBER OF SUBREGIONS
C         NMETHD    I  NUMBER OF METHODS
C         NPARAM    I  NUMBER OF PARAMETERS
C         NVMETH    I  NUMBER OF VERTICAL METHODS
C         NVPARM    I  NUMBER OF VERTICAL PARAMETES
C         NPRFHT    I  NUMBER OF VERTICAL PROFILES
C         NMETSC    I  NUMBER OF METEOROLOGICAL SCALARS
C         NSCLFT    I  NUMBER OF REMAINING WORDS IN SCRATCH
C         NSCPTR    I  NUMBER OF SCRATCH POINTERS
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL    I  NUMBER OF CELLS IN Z-DIRECTION
C         NINFIL    I  NUMBER OF INPUT FILES
C         INFILE    I  FILE UNIT NUMBERS
C         JSCRTC    I  SCRATCH FOR PARTITIONING
C         NVARBL    I  TOTAL NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C
C OUTPUTS --
C         NVARBL    I  NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NWORDS    I  NUMBER OF WORDS IN A VECTOR, ARRAY, OR MATRIX
C         KCRNT     I  CURRENT LOCATION OF SCRATCH POINTER
C         KSCPT     I  SCRATCH POINTER NUMBER
C         KZLOC     I  Z-LEVEL NUMBER
C         JMISSV    I  MISSING INTEGER VALUE
C         RMISSV    R  MISSING REAL VALUE
C         MBLANK    I  MISSING ALPHABETIC VALUE
C
C ROUTINES CALLED --
C         SCRSET    ALLOCATES SCRATCH TO AN ARRAY
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE VALUE FOR VARIABLE COUNT
C         -3        SCRATCH POINTER TO POINTERS OUT OF RANGE
C         -4        ERROR IN SCRSET CALL FROM SUBROUTINE SCRPRT
C         -5        STATION, POINT SOURCE, BOUNDRY LINE CONFLICT
C         -6        NONPOSITIVE VALUE FOR POINT SOURCE TYPE COUNT
C         -7        GRID MISSING
C         -8        NONPOSITIVE VALUE FOR SUBREGION COUNT
C         -9        POINT SOURCE,  BOUNDRY LINE CONFLICT
C         -10       NONPOSITIVE VALUE FOR NUMBER OF INPUT FILES
C         -11       NONPOSITIVE VALUE FOR Z-LEVEL COUNT
C
C OTHER INFORMATION --
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION INFILE(NINFIL)
      DIMENSION JSCRTC(NSCLFT)
      DIMENSION JSCPTR(NSCPTR)
C
C COMMON FOR 3D TEMPERATURE FLAG
C
      COMMON /TMPCON/ L3DTMP
      LOGICAL L3DTMP
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA MBLANK /1H /
      DATA RMISSV /-9.0/
      DATA JMISSV /-9/
      DATA KCRNT /1/
C
C INITIALIZE COMPLETION CODE AND TEST NAME LENGTH FOR POSITIVE
C
      JFLAG = 0
      IF (NAMLEN .LE. 0) GO TO 905
C
C SET INITIAL VARIABLE COUNT AND TEST FOR POSITIVE -- SET UNIT COUNT
C
      NVARBL = NINVAR + NSPECS
      IF (NVARBL .LE. 0) GO TO 910
      NUNITS = NVARBL
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 1
C
      KSCPT = 1
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C VARIABLES NAMES -- ADJUST COUNTERS/POINTERS
C
      NWORDS = NAMLEN * NVARBL
      KCRNT = KCRNT + NWORDS
      NSCLFT = NSCLFT - NWORDS
C
C IF THERE ARE USER DEFINED VARIABLES, ADD THEM TO LIST
C
      IF (NUSVAR .LE. 0) GO TO 110
C
C CALL SCRATCH SET FOR VARIABLE NAMES
C
      NWORDS = NAMLEN * NUSVAR
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C UPDATE VARIABLE AND UNIT COUNT
C
      NVARBL = NVARBL + NUSVAR
      NUNITS = NVARBL
C
C IF THERE ARE UNIT-ONLY VARIABLES, ADD THEM TO LIST
C
  110 IF (NUNVAR .LE. 0) GOTO 120
C
C CALL SCRATCH SET FOR VARIABLE NAMES
C
      NWORDS = NAMLEN * NUNVAR
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C UPDATE UNIT COUNT ONLY
C
  120 NUNITS = NUNITS + NUNVAR
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 2
C
      KSCPT = 2
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR UNIT NAMES
C
      NWORDS = NAMLEN * NUNITS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 3
C
      KSCPT = 3
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR MULTIPLICATIVE FACTOR
C
      NWORDS = NUNITS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 4
C
      KSCPT = 4
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR ADDITIVE FACTOR
C
      NWORDS = NUNITS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 5
C
      KSCPT = 5
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR MOLECULAR WEIGHT
C
      NWORDS = NUNITS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C TEST FOR MET. SCALARS -- IF NOT PRESENT, SET POINTER TO ZERO
C
      IF (NMETSC .GT. 0) GO TO 123
      KSCPT = 6
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = 0
      GO TO 124
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 6
C
  123 KSCPT = 6
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR MET. SCALARS
C
      NWORDS = NMETSC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C IF ONLY MET. SCALARS, RETURN TO CALLING ROUTINE
C
  124 IF (NSCPTR .EQ. 6) GO TO 1000
C
C TEST FOR STATIONS, BOUNDARY LINES, OR POINT SOURCES
C
      IF (NSTATS .GT. 0) GO TO 130
      IF (NBLINE .GT. 0) GO TO 140
      IF (NPTSRC .GT. 0) GO TO 150
C
C NOT PRESENT -- SET POINTERS 7 THRU 11 TO ZERO AND SKIP TO SUBREGIONS
C
      DO 125 KSCPT = 7, 11
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  125 CONTINUE
      GO TO 160
C
C STATIONS ARE PRESENT -- MAKE SURE NOTHING ELSE IS
C
  130 IF (NPTSRC .GT. 0) GO TO 925
      IF (NBLINE .GT. 0) GO TO 925
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 7
C
      KSCPT = 7
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR STATION NAMES
C
      NWORDS = NAMLEN * NSTATS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 8
C
      KSCPT = 8
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR STATION VALUES
C
      NWORDS = NSTATS * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 9
C
      KSCPT = 9
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR STATION X-LOCATION
C
      NWORDS = NSTATS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 10
C
      KSCPT = 10
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR STATION Y-LOCATIONS
C
      NWORDS = NSTATS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 11
C
      KSCPT = 11
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR STATION Z-LOCATIONS
C
      NWORDS = NSTATS
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C END OF STATIONS -- SKIP TO SUBREGION PROCESSING
C
      GO TO 160
C
C BOUNDARY IS PRESENT -- MAKE SURE NOTHING ELSE IS
C
  140 IF (NSTATS .GT. 0) GO TO 925
      IF (NPTSRC .GT. 0) GO TO 925
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 7
C
      KSCPT = 7
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE NAMES
C
      NWORDS = NAMLEN * NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 8
C
      KSCPT = 8
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE VALUES
C
      NWORDS = NVARBL * NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 9
C
      KSCPT = 9
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE X-BEGINNING
C
      NWORDS = NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 10
C
      KSCPT = 10
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE Y-BEGINNING
C
      NWORDS = NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 11
C
      KSCPT = 11
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE X-ENDING
C
      NWORDS = NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 12
C
      KSCPT = 12
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE Y-ENDING
C
      NWORDS = NBLINE
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C END OF BOUNDARY LINES -- SET POINTER 13 TO ZERO AND SKIP TO METHODS
C
      KSCPT = 13
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = 0
      GO TO 180
C
C POINT SOURCES ARE PRESENT -- MAKE SURE NOTHING ELSE IS
C
  150 IF (NSTATS .GT. 0) GO TO 925
      IF (NBLINE .GT. 0) GO TO 925
C
C VERIFY NUMBER OF POINT SOURCE TYPES
C
      IF (NPTSRT .LE. 0) GO TO 930
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 7
C
      KSCPT = 7
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE NAMES
C
      NWORDS = NAMLEN * NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 8
C
      KSCPT = 8
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE TYPE NAMES
C
      NWORDS = NAMLEN * NPTSRT
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 9
C
      KSCPT = 9
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE X-LOCATIONS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 10
C
      KSCPT = 10
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE Y-LOCATIONS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 11
C
      KSCPT = 11
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE TYPES
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 12
C
      KSCPT = 12
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE EMISSION BASE VALUES
C
      NWORDS = NPTSRC * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 13
C
      KSCPT = 13
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE EMISSION FACTOR VALUES
C
      NWORDS = NPTSRC * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C END OF POINT SOURCES -- SKIP TO METHODS
C
      GO TO 180
C
C TEST FOR NUMBER OF SUBREGIONS
C
  160 IF (NSUBRG .GT. 0) GO TO 170
C
C NOT PRESENT -- SET POINTERS 12 AND 13 TO ZERO AND SKIP TO METHODS
C
      DO 165 KSCPT = 12, 13
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  165 CONTINUE
      GO TO 180
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 12
C
  170 KSCPT = 12
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR SUBREGION NAMES
C
      NWORDS = NAMLEN * NSUBRG
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C VERIFY THAT BOTH ELEMENTS OF THE GRID ARE PRESENT
C
      IF (NXCELL .LE. 0) GO TO 935
      IF (NYCELL .LE. 0) GO TO 935
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 13
C
      KSCPT = 13
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR SUBREGION GRID
C
      NWORDS = NXCELL * NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C TEST NUMBER OF METHODS
C
  180 IF (KSCPT .GT. NSCPTR) GO TO 915
      IF (NMETHD .GT. 0) GO TO 190
C
C NOT PRESENT -- SET POINTERS 14 THRU 20 TO ZERO AND
C SKIP TO VERTICAL METHODS
C
      DO 185 KSCPT = 14,20
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  185 CONTINUE
      GO TO 220
C
C CHECK NUMBER OF SUBREGIONS -- MUST BE PRESENT FOR METHODS
C
  190 IF (NSUBRG .LE. 0) GO TO 940
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 14
C
      KSCPT = 14
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR METHOD NUMBERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 15
C
      KSCPT = 15
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR METHOD MINIMUM VALUES
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 16
C
      KSCPT = 16
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR METHOD MAXIMUM VALUES
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 17
C
      KSCPT = 17
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR METHOD PARAMETER POINTERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 18
C
      KSCPT = 18
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR METHOD PARAMETER COUNTERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C TEST FOR PARAMETERS
C
      IF (NPARAM .GT. 0) GO TO 210
C
C NOT PRESENT -- SET POINTERS 19 AND 20 TO ZERO AND
C SKIP TO VERTICAL METHODS
C
      DO 195 KSCPT = 19,20
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  195 CONTINUE
      GO TO 220
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 19
C
  210 KSCPT = 19
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PARAMETER NAMES
C
      NWORDS = NAMLEN * NPARAM
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 20
C
      KSCPT = 20
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PARAMETER VALUES
C
      NWORDS = NPARAM
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C SET POINTER 21 TO ZERO AND TEST NUMBER OF VERTICAL METHODS
C
  220 KSCPT = 21
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = 0
      IF (NVMETH .GT. 0) GO TO 230
C
C NOT PRESENT -- SET POINTERS 22 THRU 28 TO ZERO AND
C SKIP TO VERTICAL PROFILES
C
      DO 225 KSCPT = 22,28
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  225 CONTINUE
      GO TO 250
C
C CHECK NUMBER OF SUBREGIONS -- MUST BE PRESENT FOR VERTICAL METHODS
C
  230 IF (NSUBRG .LE. 0) GO TO 945
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 22
C
      KSCPT = 22
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL METHOD NUMBERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 23
C
      KSCPT = 23
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL METHOD MINIMUM VALUES
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 24
C
      KSCPT = 24
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL MAXIMUM VALUES
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 25
C
      KSCPT = 25
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL PARAMETER POINTERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 26
C
      KSCPT = 26
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VETICAL PARAMETER COUNTERS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C TEST FOR VERTICAL PARAMETERS
C
      IF (NVPARM .GT. 0) GO TO 240
C
C NOT PRESENT -- SET POINTERS 27 AND 28 TO ZERO AND
C SKIP TO VERTICAL PROFILES
C
      DO 235 KSCPT = 27,28
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  235 CONTINUE
      GO TO 250
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 27
C
  240 KSCPT = 27
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL PARAMETER NAMES
C
      NWORDS = NAMLEN * NVPARM
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 28
C
      KSCPT = 28
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VERTICAL PARAMETER VALUES
C
      NWORDS = NVPARM
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C TEST FOR POINT SOURCES OR VERTICAL PROFILES
C
  250 IF (NPTSRC .GT. 0) GO TO 260
      IF (NPRFHT .GT. 0) GO TO 270
C
C NOT PRESENT -- SET POINTERS 29 THRU 32 TO ZERO AND
C SKIP TO INPUT FILES
C
      DO 255 KSCPT = 29,32
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = 0
  255 CONTINUE
      GO TO 280
C
C POINT SOURCES ARE PRESENT -- MAKE SURE PROFILES ARE NOT
C
  260 IF (NPRFHT .GT. 0) GO TO 945
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 29
C
      KSCPT = 29
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE STACK HEIGHT
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 30
C
      KSCPT = 30
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE STACK DIAMETER
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 31
C
      KSCPT = 31
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE STACK EXIT TEMPERATURE
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 32
C
      KSCPT = 32
      IF(KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE STACK EXIT VELOCITY
C
      NWORDS = NPTSRC
      CALL SCRSET(IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF(JFLAG .NE. 0) GO TO 920
C
C END OF POINT SOURCES -- SKIP TO INPUT FILES
C
      GO TO 280
C
C PROFILES ARE PRESENT -- MAKE SURE POINT SOURCES ARE NOT, SUBREGIONS ARE
C
  270 IF (NPTSRC .GT. 0) GO TO 945
      IF (NSUBRG .LE. 0) GO TO 940
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 29
C
      KSCPT = 29
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PROFILE X-LOCATIONS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 30
C
      KSCPT = 30
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PROFILE Y-LOCATIONS
C
      NWORDS = NSUBRG * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 31
C
      KSCPT = 31
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PROFILE HEIGHTS
C
      NWORDS = NSUBRG * NPRFHT * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 32
C
      KSCPT = 32
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PROFILE VALUES
C
      NWORDS = NSUBRG * NPRFHT * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C SET LOOP OVER ALL INPUT FILES AND SCRATCH POINTER NUMBER
C
  280 IF(NINFIL .LE. 0) GO TO 300
      DO 295 K = 1,NINFIL
         KSCPT = 32+K
         IF (KSCPT .GT. NSCPTR) GO TO 915
C
C SEE IF THIS FILE IS PRESENT
C
         IF (INFILE(K) .GT. 0) GO TO 290
C
C NOT PRESENT -- SET POINTER TO ZERO AND SKIP TO NEXT FILE
C
         JSCPTR(KSCPT) = 0
         IF (K .EQ. 6) JSCPTR(KSCPT+1) = 0
         GO TO 295
C
C FILE IS PRESENT -- CHECK X AND Y AND, IF WIND, Z
C
  290    IF (NXCELL .LE. 0) GO TO 935
         IF (NYCELL .LE. 0) GO TO 935
         IF (NZCELL .LE. 0 .AND. K .EQ. 6) GO TO 955
C
C PLACE CURRENT SCRATCH LOCATION IN PROPER POINTER AND SET ARRAY SIZE
C
         JSCPTR(KSCPT) = KCRNT
         NWORDS = NXCELL * NYCELL
C
C SPECIAL CASES FOR TOPCON, MET. SCALARS, WINDS, AND UAMV HEIGHT
C
      IF (K .EQ. 3) GO TO 295
         IF (K .EQ. 5) GO TO 295
         IF (K .EQ. 6) NWORDS = NWORDS * NZCELL
         IF (INFILE(K) .GT. 1000) NWORDS = NWORDS * NZCELL
C
C SPECIAL CASE FOR TEMPERATURE
C
         IF (K .EQ. 4 .AND. L3DTMP) NWORDS = NWORDS * NZCELL
C
C CALL SCRATCH SET FOR ARRAY
C
         CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC,
     $               JFLAG)
         IF (JFLAG .NE. 0) GO TO 920
C
C IF THIS IS WIND, ANOTHER MATRIX IS NEEDED
C
         IF (K .NE. 6) GO TO 295
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 39
C
         KSCPT = 39
         IF (KSCPT .GT. NSCPTR) GO TO 915
         JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR WIND V-VECTORS
C
         CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC,
     $                JFLAG)
         IF (JFLAG .NE. 0) GO TO 920
C
C END OF FILES LOOP
C
  295 CONTINUE
C
C VERIFY THAT BOTH ELEMENTS OF THE GRID ARE PRESENT
C
  300 IF(NXCELL .LE. 0) GO TO 935
      IF (NYCELL .LE. 0) GO TO 935
      IF (NPTSRC .LE. 0  .AND.  NBLINE .LE. 0) GO TO 1000
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 40
C
      KSCPT = 40
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR PRINT GRID
C
      NWORDS = NXCELL * NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, MBLANK, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C POINT SOURCES AND BOUNDARIES ARE HANDLED SEPARATELY
C
      IF(NPTSRC .GT. 0) GO TO 310
      IF(NBLINE .GT. 0) GO TO 320
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 41
C
  310 KSCPT = 41
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE X-LOCATIONS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 42
C
      KSCPT = 42
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE Y-LOCATIONS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 43
C
      KSCPT = 43
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE Z-LOCATIONS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 44
C
      KSCPT = 44
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE PLUME HEIGHT
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 45
C
      KSCPT = 45
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE FLOW RATE
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 46
C
      KSCPT = 46
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR POINT SOURCE EMISSION FLUXES
C
      NWORDS = NPTSRC * NVARBL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 47
C
      KSCPT = 47
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VECTOR OF POINT SOURCE NUMBERS
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 48
C
      KSCPT = 48
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR VECTOR OF EMISSIONS FOR 1 SPECIES
C
      NWORDS = NPTSRC
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C VERIFY THAT ALL ELEMENTS OF THE GRID ARE PRESENT
C
  320 IF (NXCELL .LE. 0) GO TO 935
      IF (NYCELL .LE. 0) GO TO 935
      IF (NZCELL .LE. 0) GO TO 955
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 41
C
      KSCPT = 41
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE REFERENT - WEST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 42
C
      KSCPT = 42
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE REFERENT - EAST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 43
C
      KSCPT = 43
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE REFERENT - SOUTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 44
C
      KSCPT = 44
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY LINE REFERENT - NORTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 45
C
      KSCPT = 45
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY INDEX - WEST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 46
C
      KSCPT = 46
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY INDEX - EAST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 47
C
      KSCPT = 47
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY INDEX - SOUTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 48
C
      KSCPT = 48
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY INDEX - NORTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 49
C
      KSCPT = 49
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT SEGMENT - WEST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 50
C
      KSCPT = 50
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT SEGMENT - EAST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 51
C
      KSCPT = 51
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT SEGMENT - SOUTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 52
C
      KSCPT = 52
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT SEGMENT - NORTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 53
C
      KSCPT = 53
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT X-LOCATION - WEST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 54
C
      KSCPT = 54
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT X-LOCATION - EAST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 55
C
      KSCPT = 55
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT X-LOCATION - SOUTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 56
C
      KSCPT = 56
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT X-LOCATION - NORTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 57
C
      KSCPT = 57
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT Y-LOCATION - WEST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 58
C
      KSCPT = 58
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT Y-LOCATION - EAST
C
      NWORDS = NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 59
C
      KSCPT = 59
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT Y-LOCATION - SOUTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 60
C
      KSCPT = 60
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY ADJACENT Y-LOCATION - NORTH
C
      NWORDS = NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, JMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 61
C
      KSCPT = 61
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY CONCENTRATIONS - WEST
C
      NWORDS = NVARBL * NZCELL * NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 62
C
      KSCPT = 62
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY CONCENTRATIONS - EAST
C
      NWORDS = NVARBL * NZCELL * NYCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 63
C
      KSCPT = 63
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY CONCENTRATIONS - SOUTH
C
      NWORDS = NVARBL * NZCELL * NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C PLACE CURRENT SCRATCH LOCATION IN POINTER 64
C
      KSCPT = 64
      IF (KSCPT .GT. NSCPTR) GO TO 915
      JSCPTR(KSCPT) = KCRNT
C
C CALL SCRATCH SET FOR BOUNDARY CONCENTRATIONS - NORTH
C
      NWORDS = NVARBL * NZCELL * NXCELL
      CALL SCRSET (IPRINT, NSCLFT, NWORDS, KCRNT, RMISSV, JSCRTC, JFLAG)
      IF (JFLAG .NE. 0) GO TO 920
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  905 WRITE (IPRINT,2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE VARIABLE COUNT
C
  910 WRITE (IPRINT,2910) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR POINTER TO SCRATCH POINTERS , OUT OF RANGE
C
  915 WRITE (IPRINT,2915) KSCPT, NSCPTR
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SCRATCH SET
C
  920 WRITE (IPRINT,2920) JFLAG, KSCPT
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR STATION, POINT SOURCE, BOUNDARY LINE CONFLICT
C
  925 WRITE (IPRINT,2925) NSTATS, NSUBRG, NPTSRC, NBLINE
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE POINT SOURCE TYPE COUNT
C
  930 WRITE (IPRINT,2930) NPTSRT
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR GRID MISSING
C
  935 WRITE (IPRINT,2935) NXCELL, NYCELL
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE SUBREGION COUNT
C
  940 WRITE (IPRINT,2940) NSUBRG
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR POINT SOURCE, BOUNDARY LINE CONFLICT
C
  945 WRITE (IPRINT,2945) NPTSRC, NBLINE
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE Z-LEVEL COUNT
C
  955 WRITE (IPRINT,2955) NZCELL
      JFLAG = -11
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        45H SUBROUTINE SCRPRT CALL WITH NAME LENGTH OF, I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE SCRPRT CALLED WITH VARIABLE COUNT OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        34H THE SCRATCH VECTOR POINTER NUMBER, I10,
     $        32H EXCEEDS THE ALLOWABLE VALUE OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2920 FORMAT (1H1, 25H****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        42H RETURNED TO SCRPRT FROM SUBROUTINE SCRSET,
     $        22H FOR SCRATCH LOCATION , I10, //)
 2925 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        38H SUBROUTINE SCRPRT CALLED WITH STATION,
     $        10H COUNT OF , I10, //,
     $        40H SUBROUTINE SCRPRT CALLED WITH SUBREGION,
     $        10H COUNT OF , I10, //,
     $        43H SUBROUTINE SCRPRT CALLED WITH POINT SOURCE,
     $        10H COUNT OF , I10, //,
     $        44H SUBROUTINE SCRPRT CALLED WITH BOUNDARY LINE,
     $        10H COUNT OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2930 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        48H SUBROUTINE SCRPRT CALLED WITH POINT SOURCE TYPE,
     $        10H COUNT OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2935 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        47H SUBROUTINE SCRPRT CALLED WITH X-DIRECTION CELL,
     $        10H COUNT OF , I10, //,
     $        47H SUBROUTINE SCRPRT CALLED WITH Y-DIRECTION CELL,
     $        10H COUNT OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2940 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        40H SUBROUTINE SCRPRT CALLED WITH SUBREGION,
     $        10H COUNT OF, I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2945 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        43H SUBROUTINE SCRPRT CALLED WITH POINT SOURCE,
     $        10H COUNT OF , I10, //,
     $        44H SUBROUTINE SCRPRT CALLED WITH BOUNDARY LINE,
     $        10H COUNT OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        44H SUBROUTINE SCRPRT CALLED WITH VERTICAL CELL,
     $        10H COUNT OF , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
