      SUBROUTINE SCRSET(IPRINT,NSCLFT,NWORDS,KCRNT,JVALUE,JSCRTC,
     $                  JFLAG)
C
C NAME -- SET SCRATCH STORAGE
C
C DESCRIPTION -- DETERMINE WHETHER SUFFICIENT SCRATCH SPACE IS AVAIL-
C         ABLE FOR NEXT VARIABLE, INITIALIZES THE VARIABLE, AND RESETS
C         THE SCRATCH INDICES
C
C
C INPUTS --
C
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NSCLFT    I  NUMBER OF WORDS LEFT IN SCRATCH
C         NWORDS    I  NUMBER OF WORDS WANTED
C         KCRNT     I  POINTER TO CURRENT LOCATION
C         JVALUE    I  VALUE FOR CLEARING SRATCH
C         JSCRTC    I  SCRATCH VECTOR (LENGTH OF SCRATCH)
C
C OUTPUTS --
C         NSCLFT    I  NUMBER OF WORDS LEFT IN SCRATCH
C         KCRNT     I  POINTER TO CURRENT LOCATION
C         JSCRTC    I  SCRATCH VECTOR (LENGTH OF SCRATCH)
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED --
C         SINVAL    FILLS A VECTOR WITH A SINGLE VALUE
C
C ERROR CONDITIONS --
C         -1        NUMBER OF WORDS IS NON-POSITIVE
C         -2        NOT ENOUGH ROOM IN SCRATCH
C         -3        ERROR IN SINVAL
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION JSCRTC(NSCLFT)
C
C INITIALIZE COMPLETION FLAG
C
      JFLAG = 0
C
C TEST THAT SUFFICIENT SPACE IS AVAILABLE
C
      IF (NWORDS .GT. NSCLFT) GO TO 910
C
C CLEAR VECTOR TO INITIAL VALUE
C
      CALL SINVAL (IPRINT, NWORDS, JVALUE, JSCRTC(KCRNT), JFLAG)
C
C RESET POINTERS AND COUNTERS
C
      KCRNT = KCRNT + NWORDS
      NSCLFT = NSCLFT - NWORDS
C
C RETURN TO CALLER
C
      GO TO 1000
C
C ERROR MESSAGE FOR SCRATCH OVERFLOW
C
  910 NSCLFT = NWORDS - NSCLFT
      WRITE (IPRINT, 2910) NSCLFT
      NSCLFT = -NSCLFT
      JFLAG = -2
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2910 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ******  ,
     $        40H INSUFFICIENT STORAGE FOR PROGRAM ARRAYS, //, 1X,
     $        51HSTORAGE MUST BE INCREASED  OR PROBLEM SIZE REDUCED  ,
     $        13H BY AT LEAST ,I10, 7H WORDS ,//,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
      END
