      SUBROUTINE STASGN (IPRINT, NAMLEN, NSTATS, NXCELL, NYCELL, KXCLL,
     $    KYCLL, RMISSV, VALMIN, VALMAX, ONESBR, RADIUS, RADINC, RADMAX,
     $    MVARBL, XSTATL, YSTATL, STAVAL, MSTATS, JRGRID, OUTVAL, JFLAG)
C
C NAME -- STATION VALUE ASSIGNMENT
C
C DESCRIPTION -- CALCULATES STATION-BASED INTERPOLATION VALUES FOR A
C         SINGLE GRID SQUARE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NSTATS    I  NUMBER OF STATIONS
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         KXCLL     I  X-COORDINATE OF GRID CELL
C         KYCLL     I  Y-COORDINATE OF GRID CELL
C         RMISSV    R  MISSING VALUE
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C         ONESBR    R  SINGLE SUBREGION OPTION FLAG
C         RADIUS    R  RADIUS FOR STATION INCLUSION
C         RADINC    R  INCREMENT FOR INCREASE OF RADIUS
C         RADMAX    R  MAXIMUM RADIUS
C         STAVAL    R  VARIABLE VALUES
C         XSTATL    R  STATION X-LOCATIONS
C         YSTATL    R  STATION Y-LOCATIONS
C         MVARBL    I  VARIABLE NAME
C         MSTATS    I  STATION NAMES
C         JRGRID    I  SUBREGION GRID
C
C OUTPUTS --
C         OUTVAL    R  VALUE FOR THIS VARIABLE IN THIS CELL
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         KXLOC     I  X-CELL LOCATION OF STATION
C         KYLOC     I  Y-CELL LOCATION OF STATION
C         DSTMIN    R  MINIMUM ALLOWABLE DISTANCE
C         DSTNCE    R  DISTANCE FROM STATION TO SQUARE
C         RADTST    R  TEST RADIUS
C         VALNUM    R  NUMERATOR SUMMING VARIABLE
C         VALDEN    R  DENOMINATOR SUMMING VARIABLE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -7        NO ACCEPTABLE STATIONS
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN)
      character*4 MVARBL(NAMLEN)
      DIMENSION XSTATL(NSTATS)
      DIMENSION YSTATL(NSTATS)
      DIMENSION STAVAL(NSTATS)
Ctcm  DIMENSION MSTATS(NAMLEN,NSTATS)
      character*4 MSTATS(NAMLEN,NSTATS)
      DIMENSION JRGRID(NXCELL,NYCELL)
C
C SET LOCAL PARAMETERS
C
      DATA DSTMIN /0.1/
C
C SET COMPLETION FLAG AND OUTPUT VARIABLE TO INITIAL VALUE
C
      JFLAG = 0
      OUTVAL = RMISSV
C
C INITIALIZE THE NUMERATOR AND DENOMINATOR
C
      VALNUM = 0.0
      VALDEN = 0.0
C
C INITIALIZE RADIUS AND SET STATION LOOP
C
      RADTST = RADIUS
  105 DO 200 J=1,NSTATS
C
C REJECT STATION IF MISSING VALUE AND TEST FOR SINGLE SUBREGION
C
         IF (STAVAL(J) .EQ. RMISSV) GO TO 200
         IF (ONESBR .EQ. RMISSV) GO TO 125
         IF (ONESBR .EQ. 0.0) GO TO 125
C
C REJECT STATION IF NOT IN THIS SUBREGION
C
         KXLOC = IFIX(XSTATL(J)) + 1
         KYLOC = IFIX(YSTATL(J)) + 1
         IF (JRGRID(KXLOC, KYLOC) .NE. JRGRID(KXCLL, KYCLL)) GO TO 200
C
C STATION IS ACCEPTABLE -- CALCULATE AND TEST DISTANCE
C
  125    DSTNCE = SQRT((FLOAT(KXCLL) - 0.5 - XSTATL(J)) ** 2 +
     $                 (FLOAT(KYCLL) - 0.5 - YSTATL(J)) ** 2)
         IF (DSTNCE .GT. RADTST) GO TO 200
         IF (DSTNCE .LT. DSTMIN) DSTNCE = DSTMIN
C
C INCREMENT NUMERATOR AND DENOMINATOR
C
         VALNUM = VALNUM + STAVAL(J) / DSTNCE
         VALDEN = VALDEN + 1.0 / DSTNCE
C
C END LOOP AND CHECK FOR AT LEAST ONE VALID STATION
C
  200 CONTINUE
      IF (VALDEN .GT. 0.0) GO TO 225
C
C NO ACCEPTABLE STATIONS -- INCREMENT AND TEST RADIUS
C
      IF (RADTST .GE. RADMAX) GO TO 935
      RADTST = RADTST + RADINC
      IF (RADTST .GT. RADMAX) RADTST = RADMAX
C
C WRITE MESSAGE REGARDING INCREMENT AND GO AROUND AGAIN
C
      GO TO 105
C
C CALCULATE OUTPUT VALUE, CHECK ITS RANGE, AND RETURN
C
  225 OUTVAL = VALNUM /VALDEN
      IF (OUTVAL .GE. VALMIN) GO TO 235
      WRITE (IPRINT, 2235) (MVARBL(II),II=1,NAMLEN), KXCLL, KYCLL,
     $        VALMIN
      OUTVAL = VALMIN
      GO TO 1000
  235 IF (OUTVAL .LE. VALMAX) GO TO 1000
      WRITE (IPRINT, 2245) (MVARBL(II),I=1,NAMLEN), KXCLL, KYCLL,
     $        VALMAX
      OUTVAL = VALMAX
      GO TO 1000
C
C ERROR MESSAGE FOR NO ACCEPTABLE STATIONS
C
  935 WRITE (IPRINT, 2935) (MVARBL(II),II=1,NAMLEN), KXCLL, KYCLL
      JFLAG = -7
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2225 FORMAT (49H ****** NOTE ****** THE STATION INCLUSION RADIUS ,
     $        23H HAS BEEN INCREASED TO ,F10.4, //,
     $        14H FOR VARIABLE , 10A1, 10H IN CELL (, I10, 1H,,
     $        I10, 2H)., //)
 2235 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H) //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2245 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H) //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2935 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ****** ,
     $        46H NO ACCEPTABLE STATION WAS FOUND FOR VARIABLE , 10A1,
     $        //, 23H FOR THE GRID CELL X = , I10, 5H Y = , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
