      SUBROUTINE STVLRD (INCARD, IPRINT, NAMLEN, NVARBL, NSTATS, LINPTP,
     $                   LSTRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $                   MSTATS, STATVL, JFLAG)
C
C NAME -- STATION VALUES PACKET READ
C
C DESCRIPTION -- READS THE STATION VALUES PACKET AS PART OF TIME-
C                INVARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NSTATS    I  NUMBER OF STATIONS
C         LINPTP    I  INPUT PRINT FLAG
C         LSTRDP    I  STATION VALUES TABLE PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MSTATS    I  STATION NAMES
C
C OUTPUTS --
C         STATVL    R  STATION VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         MENDSV    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         MSTANM    I  STATION NAME
C         MVARNM    I  VARIABLE NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         KBEGV     I  POINTER TO BEGINNING VARIABLE LOCATION
C         KENDV     I  POINTER TO ENDING VARIABLE LOCATION
C         KBEGS     I  POINTER TO BEGINNING STATION LOCATION
C         KENDS     I  POINTER TO ENDING STATION LOCATION
C         KSTAT     I  STATION POINTER
C         KVRBL     I  VARIABLE POINTER
C         VALSTA    R  STATION VALUE
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -8        STATION NAME NOT IN STATION LIST
C         -12       VARIABLE NAME NOT IN VARIABLE LIST
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LSTRDP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
Ctcm  DIMENSION MSTATS(NAMLEN,NSTATS)
      character*4 MSTATS(NAMLEN,NSTATS)
      DIMENSION STATVL(NSTATS,NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MENDSV(10), MSTANM(10), MVARNM(10), MCRDID(20)
      character*4 MENDSV(10), MSTANM(10), MVARNM(10), MCRDID(20)
Ctcm  DIMENSION MALLNM(10)
      character*4 MALLNM(10)
C
C DECLARE PACKET TRAILER AND 'ALL' REFERENCE
C
      DATA MENDSV /'E', 'N', 'D', 7*' '/
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSTANM, MVARNM, VALSTA, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSTANM, MVARNM, VALSTA, MCRDID
C
C PACK STATION NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MSTANM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSTANM, MENDSV, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C COMPARE STATION NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MSTANM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET STATION POINTER TO ZERO TO INDICATE 'ALL'
C
      KSTAT = 0
      GO TO 140
C
C SET LOOP TO FIND STATION NAME
C
  113 DO 115 J = 1, NSTATS
C
C COMPARE INPUT STATION NAME WITH THE LIST OF STATION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSTANM, MSTATS(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND STATION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSTAT = J
         GO TO 140
C
C END LOOP AND ERROR MESSAGE
C
  115 CONTINUE
      GO TO 940
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF STANDARD VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C SAVE LOCATION AND SKIP TO UNIT CONVERSION
C
         KVRBL = J
         GO TO 150
C
C END LOOP AND ERROR MESSAGE
C
  145 CONTINUE
      GO TO 960
C
C DO UNIT CONVERSION ON INPUT VALUE, UNLESS MISSING
C
  150 KBEGV = KVRBL
      IF (VALSTA .EQ. RMISSV) GO TO 160
C
C USE FIRST CONVERSION IF ALL
C
      IF (KVRBL .EQ. 0) KVRBL = 1
      CALL UNTCNV (VALSTA, FACMLT(KVRBL), FACADD(KVRBL), SMOLWT(KVRBL),
     $             RMISSV, RMISSV, VALSTA)
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  160 KVRBL = KBEGV
      KENDV = KVRBL
      KBEGS = KSTAT
      KENDS = KSTAT
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KSTAT .EQ. 0) KBEGS = 1
      IF (KSTAT .EQ. 0) KENDS = NSTATS
C
C SET LOOPS FOR STORING INPUT
C
      DO 185 KVRBL = KBEGV, KENDV
         DO 175 KSTAT = KBEGS, KENDS
C
C STORE VALUE IN TABLE
C
            STATVL(KSTAT, KVRBL) = VALSTA
C
C END LOOPS AND GET NEXT CARD
C
  175    CONTINUE
  185 CONTINUE
      GO TO 105
C
C END OF PACKET, PRINT VALUES TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LSTRDP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 225 K = 1, NSTATS
         DO 215 J = 1, NVARBL
            WRITE (IPRINT, 2215)(MSTATS(I,K), I=1,NAMLEN),
     $                       (MVARBL(I,J), I=1,NAMLEN), STATVL(K,J)
  215    CONTINUE
  225 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR STATION NAME NOT IN STATION LIST
C
  940 WRITE (IPRINT, 2940) MSTANM
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  960 WRITE (IPRINT, 2960) MVARNM
      JFLAG = -12
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, F10.0, 30X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, F10.4, 30X, 20A1)
 2210 FORMAT (1H1, 20X, 20HSTATION VALUES TABLE, //,
     $        46H STATION NAME   VARIABLE NAME   STATION VALUE , //)
 2215 FORMAT (1X, 10A1, 5X, 10A1, F15.4, /)
 2940 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        31H UNABLE TO LOCATE STATION NAME , 10A1,
     $        18H IN STATIONS TABLE, //,
     $        27H CHECK STATION SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2960 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLES TABLE, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
