      SUBROUTINE VPRFRD (INCARD, IPRINT, NAMLEN, NVARBL, NUNITS,
     $    NSBRGN, NPRFHT, NXCELL, NYCELL, LINPTP, LVPRFP,
     $    XREGOR, YREGOR, XCELLD, YCELLD,
     $    RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MSBRGN,
     $    XPROFL, YPROFL, PRFHGT, PRFVAL, JFLAG)
C
C NAME -- VERTICAL PROFILE PACKET READ
C
C DESCRIPTION -- READS THE VERTICAL PROFILE PACKET AS PART OF
C                TIME-VARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NPRFHT    I  NUMBER OF PROFILE HEIGHTS
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         LINPTP    I  INPUT PRINT FLAG
C         LVPRFP    I  VERTICAL PROFILE TABLE PRINT FLAG
C         XREGOR    R  X-COORDINATE OF REGION ORIGIN
C         YREGOR    R  Y-COORDINATE OF REGION ORIGIN
C         XCELLD    R  CELL LENGTH IN X-DIRECTION
C         YCELLD    R  CELL LENGTH IN Y-DIRECTION
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MSBRGN    I  SUBREGION NAMES
C
C OUTPUTS --
C         XPROFL    R  X-COORDINATES OF PROFILE LOCATIONS
C         YPROFL    R  Y-COORDINATES OF PROFILE LOCATIONS
C         PRFHGT    R  SET OF PROFILE HEIGHTS
C         PRFVAL    R  SET OF PROFILE VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         NPRFVL    I  NUMBER OF PROFILE HEIGHTS FOR THIS SUBREGION
C         KSBRG     I  CURRENT SUBREGION NUMBER
C         KVRBL     I  CURRENT VARIABLE NUMBER
C         KPROF     I  CURRENT VERTICAL PROFILE LOCATION
C         KCOOR     I  POINTER TO 'COORD' IN VARIABLE NAME LIST
C         KHGHT     I  POINTER TO 'HEIGHT' IN VARIABLE NAME LIST
C         KVLOC     I  LOCAL VARIABLE POINTER
C         KBEGS     I  BEGINNING LOCATION FOR SUBREGION LOOP
C         KENDS     I  ENDING LOCATION FOR SUBREGION LOOP
C         KBEGV     I  BEGINNING LOCATION FOR VARIABLE LOOP
C         KENDV     I  ENDING LOCATION FOR VARIABLE LOOP
C         MVARNM    I  INPUT VARIABLE NAME
C         MSBRNM    I  INPUT SUBREGION NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         MCOORD    I  REFERENCE NAME FOR 'COORD'
C         MHIGHT    I  REFERENCE NAME FOR 'HEIGHT'
C         MENDVP    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         PROFXL    R  X-COORDINATE OF THIS PROFILE
C         PROFYL    R  Y-COORDINATE OF THIS PROFILE
C         HTPROF    R  INDIVIDUAL PROFILE HEIGHT
C         VLPROF    R  INDIVIDUAL PROFILE VALUE
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -11       'COORD' NOT FOUND
C         -13       'HEIGHT' NOT FOUND
C         -18       SUBREGION NAME NOT FOUND
C         -22       VARIABLE NAME NOT FOUND
C         -23       NUMBER OF PROFILE VALUES OUT OF RANGE
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LVPRFP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
Ctcm  DIMENSION MVARBL(NAMLEN, NUNITS)
      character*4 MVARBL(NAMLEN, NUNITS)
Ctcm  DIMENSION MSBRGN(NAMLEN, NSBRGN)
      character*4 MSBRGN(NAMLEN, NSBRGN)
      DIMENSION XPROFL(NSBRGN, NVARBL)
      DIMENSION YPROFL(NSBRGN, NVARBL)
      DIMENSION PRFHGT(NPRFHT, NSBRGN, NVARBL)
      DIMENSION PRFVAL(NPRFHT, NSBRGN, NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MVARNM(10), MENDVP(10), MCRDID(20)
      character*4 MVARNM(10), MENDVP(10), MCRDID(20)
Ctcm  DIMENSION MCOORD(10), MHIGHT(10), MSBRNM(10), MALLNM(10)
      character*4 MCOORD(10), MHIGHT(10), MSBRNM(10), MALLNM(10)
C
C DECLARE PACKET TRAILER, 'ALL', 'COORD', AND 'HEIGHT'
C
      DATA MENDVP /'E', 'N', 'D', 7*' '/
      DATA MALLNM /'A', 'L', 'L', 7*' '/
      DATA MCOORD /'C', 'O', 'O', 'R', 'D', ' ', ' ', ' ', ' ', ' '/
      DATA MHIGHT /'H', 'E', 'I', 'G', 'H', 'T', ' ', ' ', ' ', ' '/
      DATA JMISSV /-9/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C FIND COORD IN VARIABLE LIST
C
      DO 45 J = 1, NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MCOORD, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 45
C
C FOUND IT -- SAVE LOCATION
C
         KCOOR = J
         GO TO 50
C
C END LOOP -- IF NOT FOUND, COORD IS MISSING FROM LIST
C
   45 CONTINUE
      GO TO 922
C
C FIND HEIGHT IN VARIABLE LIST
C
   50 DO 55 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MHIGHT, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 55
C
C FOUND IT -- SAVE LOCATION
C
         KHGHT = J
         GO TO 105
C
C END LOOP -- IF NOT FOUND, HEIGHT IS MISSING FROM LIST
C
   55 CONTINUE
      GO TO 926
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSBRNM, MVARNM,
     $     PROFXL, PROFYL, NPRFVL, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSBRNM, MVARNM,
     $     PROFXL, PROFYL, NPRFVL, MCRDID
C
C PACK SUGREGION NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MSBRNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MENDVP, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 410
C
C COMPARE SUBREGION NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET SUBREGION POINTER TO ZERO TO INDICATE 'ALL'
C
      KSBRG = 0
      GO TO 120
C
C SET LOOP TO FIND SUBREGION NAME
C
  113 DO 115 K = 1, NSBRGN
C
C COMPARE INPUT SUBREGION NAME WITH THE LIST OF SUBREGION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MSBRGN(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND SUBREGION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSBRG = K
         GO TO 120
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  115 CONTINUE
      GO TO 950
C
C PACK VARIABLE NAME
C
  120 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 123
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 140
C
C SET LOOP TO FIND VARIABLE NAME
C
  123 DO 125 K = 1, NVARBL
C
C COMPARE INPUT VARIABLE NAME WITH THE LIST OF VARIABLE NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 125
C
C FOUND VARIABLE NAME -- SAVE LOCATION AND SKIP OUT
C
         KVRBL = K
         GO TO 140
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  125 CONTINUE
      GO TO 970
C
C DO UNIT CONVERSION FOR X-AND Y-LOCATIONS
C
  140 CALL UNTCNV(PROFXL, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, PROFXL)
      CALL UNTCNV(PROFYL, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, PROFYL)
C
C CHECK NUMBER OF PROFILE VALUES
C
      IF (NPRFVL .NE. JMISSV) GO TO 141
      NSTART = 1
      GO TO 142
  141 IF (NPRFVL .LE. 1) GO TO 975
      IF (NPRFVL .GT. NPRFHT) GO TO 975
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  142 KBEGV = KVRBL
      KENDV = KVRBL
      KBEGS = KSBRG
      KENDS = KSBRG
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KSBRG .EQ. 0) KBEGS = 1
      IF (KSBRG .EQ. 0) KENDS = NSBRGN
C
C CONVERT TO GRID UNITS AND STORE INPUT DATA FOR APPROPRIATE
C SUBREGIONS AND VARIABLES
C
      DO 155 J = KBEGV, KENDV
         DO 145 K = KBEGS, KENDS
            XPROFL(K, J) = (PROFXL - XREGOR) / XCELLD
            YPROFL(K, J) = (PROFYL - YREGOR) / YCELLD
  145    CONTINUE
  155 CONTINUE
      IF (NPRFVL .EQ. JMISSV) GO TO 247
C
C SET READ LOOP FOR HEIGHT AND VALUE CARDS
C
      DO 245 KPROF = 1, NPRFVL
C
C READ AND, IF WANTED, PRINT THE PROFILE CARD
C
         READ (INCARD, 1185) HTPROF, VLPROF, MCRDID
         IF (LINPTP) WRITE (IPRINT, 2185) HTPROF, VLPROF, MCRDID
C
C DO UNIT CONVERSION ON HEIGHT
C
         IF (HTPROF .EQ. RMISSV) GO TO 210
         CALL UNTCNV(HTPROF, FACMLT(KHGHT), FACADD(KHGHT),
     $        SMOLWT(KHGHT), RMISSV, RMISSV, HTPROF)
C
C DO UNIT CONVERSION ON VALUE -- ASSUME FIRST VARIABLE IF 'ALL'
C
         KVLOC = KVRBL
         IF (KVLOC .EQ. 0) KVLOC = 1
         CALL UNTCNV(VLPROF, FACMLT(KVLOC), FACADD(KVLOC),
     $        SMOLWT(KVLOC), RMISSV, RMISSV, VLPROF)
C
C SET LOOPS FOR STORING INPUT
C
  210    DO 235 J = KBEGV, KENDV
            DO 225 K = KBEGS, KENDS
C
C STORE PROFILE HEIGHT AND VALUE
C
               PRFHGT(KPROF, K, J) = HTPROF
               PRFVAL(KPROF, K, J) = VLPROF
C
C END LOOPS AND GET NEXT CARD
C
  225       CONTINUE
  235    CONTINUE
  245 CONTINUE
C
C FILL IN REMAINING HEIGHTS AND VALUES WITH MISSING VALUE
C
      IF (NPRFVL .EQ. NPRFHT) GO TO 105
      NSTART = NPRFVL + 1
  247 DO 275 KPROF = NSTART, NPRFHT
         DO 265 J = KBEGV, KENDV
            DO 255 K = KBEGS, KENDS
               PRFHGT(KPROF, K, J) = RMISSV
               PRFVAL(KPROF, K, J) = RMISSV
  255       CONTINUE
  265    CONTINUE
  275 CONTINUE
      GO TO 105
C
C END OF PACKET -- PRINT VERTICAL PROFILE TABLE IF WANTED, ELSE RETURN
C
  410 IF (.NOT. LVPRFP) GO TO 1000
      WRITE (IPRINT, 2405)
C
C SET LOOPS FOR VARIABLE AND SUBREGION AND WRITE FIRST PROFILE
C
      DO 435 K = 1, NSBRGN
         DO 425 J = 1, NVARBL
            WRITE (IPRINT, 2410) (MSBRGN(I,K), I = 1, NAMLEN),
     $                           (MVARBL(I,J), I = 1, NAMLEN),
     $                           XPROFL(K, J), YPROFL(K, J),
     $                           PRFHGT(1, K, J), PRFVAL(1, K, J)
C
C SET LOOP FOR REST OF PROFILE HEIGHTS AND VALUES
C
            DO 415 I = 2, NPRFHT
C
C IF NOT END, PRINT PROFILE HEIGHT AND VALUE
C
              IF (PRFHGT(I, K, J) .EQ. RMISSV) GO TO 425
              WRITE (IPRINT, 2415) PRFHGT(I, K, J), PRFVAL(I, K, J)
C
C END ALL LOOPS
C
  415       CONTINUE
  425    CONTINUE
  435 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR 'COORD' NOT IN VARIABLE NAME LIST
C
  922 WRITE (IPRINT, 2922) MCOORD
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR 'HEIGHT' NOT IN VARIABLE NAME LIST
C
  926 WRITE (IPRINT, 2926) MHIGHT
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR SUBREGION NAME NOT FOUND
C
  950 WRITE (IPRINT, 2950) MSBRNM
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT FOUND
C
  970 WRITE (IPRINT, 2970) MVARNM
      JFLAG = -22
      GO TO 1000
C
C ERROR MESSAGE FOR NUMBER OF PROFILE VALUES OUT OF RANGE
C
  975 WRITE (IPRINT, 2975) NPRFVL
      JFLAG = -23
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, 2F10.0, I10, 10X, 20A1)
 1185 FORMAT (F10.0, F10.0, 40X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, 2F10.4, I10, 10X, 20A1)
 2185 FORMAT (1X, F10.0, F12.4, 38X, 20A1)
 2405 FORMAT (1H1, 50X, 23HVERTICAL PROFILES TABLE, //,
     $        46H SUBREGION      VARIABLE       X-LOCATION      ,
     $        45HY-LOCATION     PROFILE HEIGHT  PROFILE VALUE   , //)
 2410 FORMAT (1X, 10A1, 5X, 10A1, 5X, 4F15.4, /)
 2415 FORMAT (1X, 60X, 2F15.4, /)
 2922 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2926 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        33H UNABLE TO LOCATE SUBREGION NAME , 10A1,
     $        19H IN SUBREGION TABLE, //,
     $        34H CHECK SUBREGION NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        18H IN VARIABLE TABLE , //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2975 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        39H THE NUMBER OF VERTICAL PROFILE VALUES , I10, //,
     $        30H IS OUTSIDE THE RANGE OF 2 TO , I10,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
