      SUBROUTINE WINDRD(IPRINT, INFILE, NXCELL, NYCELL, NZCELL, JCURDT,
     $  CURTIM, STRFHT, XMAXSP, YMAXSP, AVESPW, AVESPE, AVESPS, AVESPN,
     $  UVECTR, VVECTR, JFLAG)
C
C NAME -- WIND FILE READ
C
C DESCRIPTION -- READS THE TIME-VARIANT WIND FILE RECORD
C                WHEN TIME UPDATE IS NEEDED
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         NZCELL    I  NUMBER OF Z-CELLS
C         JCURDT    I  CURRENT DATE
C         CURTIM    R  CURRENT TIME
C
C OUTPUTS --
C         STRFHT    R  STANDARD REFERENCE HEIGHT FOR STATIONS
C         XMAXSP    R  MAXIMUM SPEED IN X-DIRECTION
C         YMAXSP    R  MAXIMUM SPEED IN Y-DIRECTION
C         AVESPW    R  AVERAGE SPEED AT THE WEST BOUNDARY
C         AVESPE    R  AVERAGE SPEED AT THE EAST BOUNDARY
C         AVESPS    R  AVERAGE SPEED AT THE SOUTH BOUNDARY
C         AVESPN    R  AVERAGE SPEED AT THE NORTH BOUNDARY
C         UVECTR    R  THE OUTPUT U-VECTOR MATRIX
C         VVECTR    R  THE OUTPUT V-VECTOR MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NSGMNT    I  NUMBER OF SEGMENTS
C         KSGMT     I  FILE SEGMENT NUMBER
C         JSTRDT    I  STARTING DATE FOR CURRENT RECORD
C         JSTPDT    I  STOPPING DATE FOR CURRENT RECORD
C         STRTIM    R  STARTING TIME FOR CURRENT RECORD
C         STPTIM    R  STOPPING TIME FOR CURRENT RECORD
C
C ROUTINES CALLED --
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         FLWDRD    READS A WIND RECORD
C         FLTMRD    READS A TIME SPAN RECORD
C
C ERROR CONDITIONS --
C         -1        TIME PRIOR TO CURRENT TIME
C         -2        ERROR IN FILE TIME READ
C         -3        ERROR IN FILE RECORD READ
C         -4        MISMATCH ON SEGMENT NUMBER
C         -5        ERROR IN VARIABLE NAME COMPARISON ROUTINE
C         -6        MISMATCH ON VARIABLE NAME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION UVECTR(NXCELL, NYCELL, NZCELL)
      DIMENSION VVECTR(NXCELL, NYCELL, NZCELL)
C
C SET DIMENSIONS OF LOCAL ARRAYS
C
Ctcm  DIMENSION MVARNM(10, 2)
      character*4 MVARNM(10, 2)
C
C INITIALIZE DATE AND TIME VALUES
C
      DATA NAMLEN /10/
      DATA JSTRDT /0/
      DATA JSTPDT /0/
      DATA STRTIM /0.0/
      DATA STPTIM /0.0/
      DATA NSGMNT /1/
      DATA NFLVAR /2/
      DATA NFLZCL /1/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C
C TEST DATE AND TIME FOR BEING IN CURRENT SPAN
C
 105  IF(CURTIM.GE.STRTIM+24.*FLOAT(JSTRDT-JCURDT).AND.
     $CURTIM.LT.STPTIM+24.*FLOAT(JSTPDT-JCURDT)) GO TO 1000
C
C TEST DATE AND TIME FOR BEING PRIOR TO CURRENT SPAN
C
      IF (JCURDT .LT. JSTRDT) GO TO 905
      IF (JCURDT .EQ. JSTRDT .AND. CURTIM .LT. STRTIM) GO TO 905
C
C READ NEXT DATE AND TIME
C
      CALL FLTMRD(IPRINT, INFILE, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 910
C
C SET LOOP OVER Z-LEVELS
C
      DO 110 J = 1, NZCELL
         KZCLL = J
C
C READ THE NEXT FILE RECORD
C
         CALL FLWDRD(IPRINT, INFILE, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $       KZCLL, KSGMT, STRFHT, XMAXSP, YMAXSP,
     $       AVESPW, AVESPE, AVESPS, AVESPN, MVARNM,
     $       UVECTR(1, 1, KZCLL), VVECTR(1, 1, KZCLL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 915
C
C CHECK THE SEGMENT NUMBER
C
         IF (KSGMT .NE. NSGMNT) GO TO 920
C
C END LOOP AND GO BACK TO TIME TEST
C
  110 CONTINUE
      GO TO 105
C
C ERROR MESSAGE FOR TIME PRIOR TO CURRENT
C
  905 WRITE (IPRINT, 2905) JCURDT, CURTIM, JSTRDT, STRTIM
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE TIME READ
C
  910 WRITE (IPRINT, 2910) JFLAG
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE RECORD READ
C
  915 WRITE (IPRINT, 2915) JFLAG, KZCLL
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON SEGMENT NUMBER
C
  920 WRITE (IPRINT, 2920) KSGMT, NSGMNT
      JFLAG = -4
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H THE CURRENT DATE , I10, 10H AND TIME , F10.2, //,
     $        28H ARE PRIOR TO THE FILE DATE , I10, 10H AND TIME ,F10.2,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT(26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURN TO WINDRD FROM SUBROUTINE FLTMRD , //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURNED TO WINDRD FROM SUBROUTINE FLWDRD ,
     $        13H FOR Z-LEVEL , I10, //)
 2920 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        25H THE FILE SEGMENT NUMBER , I10, //,
     $        43H DOES NOT MATCH THE CURRENT SEGMENT NUMBER , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
