      SUBROUTINE VERTCL (NZ, KBLOW, KELOW, KBUPP, KEUPP,
     $                   FNZLOW, FNZUP, DZS, DZS2, ZMINL, ZMINU,
     $                   DB, TOP, TH, AVHT)
      SAVE
C
C     *** CALCULATE VERTICAL DISTRIBUTION OF GRID CELLS AT A PARTICULAR
C         LOCATION
C
C--INPUT VARIABLES
C         NZ        I  NO OF Z
C         DB        R  DIFFUSION BREAK (M)
C         TOP       R  TOP OF REGION (M)
C
C--OUTPUT VARIABLES
C         TH        R  THICKNESS OF EACH CELL (M)
C         AVHT      R  AVERAGE HEIGHT OF EACH CELL (M)
C
C--ROUTINES CALLED
C         NONE
C
C--CALLED BY
C         SSIC
C         SSBC
C         STEP1
C         STEP2
C         STEP34
C         WINDZ
C
      DIMENSION  TH(NZ), AVHT(NZ)
C***********************************************************************
C
C     *** CHECK DIMENSIONS
C
C     *** FIND HEIGHT OF UPPER/LOWER BORDER
C         (I.E. TOP OF THE LOWER LAYER)
C
      TOPLOW = AMAX1 (DB, DZS + ZMINL)
      TOPLOW = AMIN1 (TOPLOW, TOP - ZMINU)
C
C     *** CALCULATE THICKNESS OF LOWER AND UPPER-LAYER CELLS
C
      THLOW = (TOPLOW - DZS)/ FNZLOW
      IF (KBUPP.NE.0) THUP = (TOP-TOPLOW)/ FNZUP
      HTSUM = 0.
C
C     *** SET VALUES FOR SURFACE LAYER, IF ANY
C
      IF (KBLOW .EQ. 1) GO TO 150
      TH(1) = DZS
      AVHT(1) = DZS2
      HTSUM = DZS
C
C     *** SET VALUES FOR LOWER LAYER
C
  150 CONTINUE
      THL2 = THLOW / 2.
      DO 200 K=KBLOW,KELOW
         TH(K) = THLOW
         AVHT(K) = HTSUM + THL2
         HTSUM = HTSUM + THLOW
  200    CONTINUE
C
C     *** SET VALUES FOR UPPER LAYER, IF ANY
C
      IF (KBUPP .EQ. 0) GO TO 9999
      THU2 = THUP / 2.
      DO 250 K=KBUPP,KEUPP
         TH(K) = THUP
         AVHT(K) = HTSUM + THU2
         HTSUM = HTSUM + THUP
  250    CONTINUE
C
 9999 RETURN
      END
